Struct GaitPose.SegmentPose

Namespace
CodeSmile.AnyMotion.AnimateYourself.Gait
/
Assembly
ApiSource.dll

Position and rotation of a body segment.

public struct GaitPose.SegmentPose
Expand Details ...

Fields

Euler

Rotation offset in degrees relative to the bind pose.

public Vector3 Euler

Field Value

Vector3

NeutralPosition

Position this segment would hold when standing still, in metres.

public Vector3 NeutralPosition

Field Value

Vector3

Position

Local-space position in metres.

public Vector3 Position

Field Value

Vector3