Interface ITextSerializer

Namespace
CodeSmile.AnyMotion.Core.SaveLoad
/
Assembly
ApiSource.dll

Converts preset data to and from a text representation. Isolated behind an interface so the format can change (eg JSON to a binary format) without touching file I/O or the save system that composes this with it.

public interface ITextSerializer
Expand Details ...

Methods

Deserialize<T>(string)

T Deserialize<T>(string text)

Parameters

Type Name Description
string
text

Returns

T

Type Parameters

T

Serialize<T>(T)

string Serialize<T>(T data)

Parameters

Type Name Description
T
data

Returns

string

Type Parameters

T