Class BandsComposer
- Namespace
- Rustaveli.Pdf
- Assembly
- Rustaveli.Pdf.dll
Builds content sandwiched between two repeating bands.
public sealed class BandsComposer
- Inheritance
-
BandsComposer
- Inherited Members
Methods
Body()
The flowing content between the bands.
public IFrame Body()
Returns
Foot()
The band drawn below the content on every page.
public IFrame Foot()
Returns
Head()
The band drawn above the content on every page.
public IFrame Head()