Table of Contents

Class DocumentPreview

Namespace
Rustaveli.Pdf
Assembly
Rustaveli.Pdf.Preview.dll

Shows documents in the browser while they are written. Run the program under dotnet watch and every saved change to the code that composes the document redraws it, without restarting.

public static class DocumentPreview
Inheritance
DocumentPreview
Inherited Members

Methods

Preview(Func<Document>, PreviewOptions?)

Shows the document compose makes, composing it again on every change, until the process is stopped — as a program written only to preview a document would. Blocks.

public static void Preview(Func<Document> compose, PreviewOptions? options = null)

Parameters

compose Func<Document>
options PreviewOptions

StartPreview(Func<Document>, PreviewOptions?)

Starts showing the document compose makes, returning the session that serves it.

public static PreviewSession StartPreview(Func<Document> compose, PreviewOptions? options = null)

Parameters

compose Func<Document>
options PreviewOptions

Returns

PreviewSession