Table of Contents

Struct ImageRequest

Namespace
Rustaveli.Pdf
Assembly
Rustaveli.Pdf.dll

What an image generated at its final size is asked for: the box it fills and the pixels that takes.

public readonly record struct ImageRequest : IEquatable<ImageRequest>
Implements
Inherited Members

Constructors

ImageRequest(Extent, int, int, float)

What an image generated at its final size is asked for: the box it fills and the pixels that takes.

public ImageRequest(Extent Size, int PixelWidth, int PixelHeight, float Resolution)

Parameters

Size Extent

The box the image fills, in points.

PixelWidth int

How many pixels across the image needs to be sharp at Resolution.

PixelHeight int

How many pixels down.

Resolution float

The resolution images are generated at, in pixels per inch.

Properties

PixelHeight

How many pixels down.

public int PixelHeight { get; init; }

Property Value

int

PixelWidth

How many pixels across the image needs to be sharp at Resolution.

public int PixelWidth { get; init; }

Property Value

int

Resolution

The resolution images are generated at, in pixels per inch.

public float Resolution { get; init; }

Property Value

float

Size

The box the image fills, in points.

public Extent Size { get; init; }

Property Value

Extent