Enum ProportionFit
- Namespace
- Rustaveli.Pdf
- Assembly
- Rustaveli.Pdf.dll
Which dimension a frame held to a proportion is fitted to: see Proportion(IFrame, float, ProportionFit).
public enum ProportionFit
Fields
Width = 0Height = 1Area = 2
Which dimension a frame held to a proportion is fitted to: see Proportion(IFrame, float, ProportionFit).
public enum ProportionFit
Width = 0Height = 1Area = 2