Enum ScriptPosition
- Namespace
- Rustaveli.Pdf
- Assembly
- Rustaveli.Pdf.dll
Vertical displacement applied to a run relative to the baseline.
public enum ScriptPosition
Fields
Normal = 0Subscript = 1Superscript = 2
Vertical displacement applied to a run relative to the baseline.
public enum ScriptPosition
Normal = 0Subscript = 1Superscript = 2