Table of Contents

Class StackComposer

Namespace
Rustaveli.Pdf
Assembly
Rustaveli.Pdf.dll

Builds the contents of a vertical stack.

public sealed class StackComposer
Inheritance
StackComposer
Inherited Members

Methods

Add()

Adds an item to the bottom of the stack and returns the frame its content goes into.

public IFrame Add()

Returns

IFrame

SpaceBetween(float)

Sets the gap inserted between consecutive items.

public void SpaceBetween(float value)

Parameters

value float