Enum TextAnchor
- Namespace
- Rustaveli.Pdf
- Assembly
- Rustaveli.Pdf.dll
Which part of a line of artwork text sits at the point it is set at.
public enum TextAnchor
Fields
Start = 0Its start.
Middle = 1Its middle.
End = 2Its end.
Which part of a line of artwork text sits at the point it is set at.
public enum TextAnchor
Start = 0Its start.
Middle = 1Its middle.
End = 2Its end.