Table of Contents

Class UnreadableFileException

Namespace
Rustaveli.Pdf
Assembly
Rustaveli.Pdf.Operations.dll

Thrown when a file cannot be read as a PDF: it is not one, or it is damaged beyond what a reader can repair.

public sealed class UnreadableFileException : Exception, ISerializable
Inheritance
UnreadableFileException
Implements
Inherited Members

Constructors

UnreadableFileException(string)

public UnreadableFileException(string message)

Parameters

message string

UnreadableFileException(string, Exception)

public UnreadableFileException(string message, Exception innerException)

Parameters

message string
innerException Exception