| AgentAvailabilityClient | |
| AgentInformation | Contains information about the Agent that has joined the Chat session. |
| AgentListener | Listener interface for retrieving Agent information during a chat session. |
| AvailabilityState | |
| AvailabilityState.Status | The agent availability client allows you to query the availability of agents attached to a particular button id. |
| ChatAnalytics | ChatAnalytics contains identifying information for analytics data that is relayed via the com.salesforce.android.service.common.analytics.ServiceAnalytics API. |
| ChatClient | ChatClient enables the interaction with the Chat Session. |
| ChatConfiguration | Configuration options for Service SDK Chat. |
| ChatConfiguration.Builder | |
| ChatCore | Entry point for configuring and creating a Service SDK Chat Session. |
| ChatEndReason | Reasons for why the session has ended. |
| ChatMessage | Contains data representing a Chat Message that has been received from the Agent. |
| ChatSentMessageReceipt | Delivery receipt for a sent chat message. |
| ChatSessionInfo | Contains information about the current Chat session. |
| ChatSessionState | The lifecycle session states for a Chat session are determined by a linear state machine. |
| ChatUI | Entry-point for Chat UI. |
| ChatUIClient | Public API for Chat UI |
| ChatUIConfiguration | Configuration information pertinent to launching Chat UI and starting Chat sessions. |
| ChatUIConfiguration.Builder | Build a new ChatUIConfiguration instance. |
| EmptyChatMessageException | Exception returned by sendChatMessage(String) via
onError(Async.ErrorHandler)
when attempting to send an empty chat message. |
| FileTransferAssistant | Enables sending a file to an Agent, which will be attached to a support case. |
| FileTransferRequestListener | Listener interface for handling File Transfer Requests from an Agent. |
| FileTransferStatus | Status of the current file transfer to the Agent. |
| PreChatConfiguration | Configuration class that determines which snapins configuration to use for pre chat forms. |
| PreChatConfiguration.Builder | |
| PreChatEntity | |
| PreChatEntity.Builder | |
| PreChatEntityField | |
| PreChatEntityField.Builder | |
| PreChatField | Class which describes a PreChatField as configured for snap-ins in your salesforce organization. |
| PreChatField.Builder | |
| PreChatField.PickListOption | Represent a PickList option as a serializable tuple. |
| PreChatField.Type | |
| PreChatUIListener | Listener interface for receiving status information about the PreChat UI. |
| QueueListener | Listener interface for retrieving queue position updates while connecting to a chat session. |
| SensitiveDataRule | Represents a text scrubbing directive that is used to replace or remove text that occurs in outgoing chat messages should they match the provided Regular Expression pattern. |
| SensitiveDataRule.Action | |
| SessionDoesNotExistException | Exception returned by ChatClient via
onError(Async.ErrorHandler)
when an action has been performed but the session does not exist. |
| SessionInfoListener | Listener interface for receiving information about the current Chat session. |
| SessionStateListener | Listener interface for receiving Chat session state and the reason for why a Chat session has ended. |