Skip to content

@arcmantle/chronicle / collection-adapters

collection-adapters

Interfaces

CollectionAdapterDeps

Defined in: collection-adapters.ts:10

Properties

getBatchFrames()

getBatchFrames: (root) => object[] | undefined

Defined in: collection-adapters.ts:11

Parameters
root

object

Returns

object[] | undefined

Functions

adaptMapMethod()

adaptMapMethod(target, currentPath, rootObject, deps, method): (...args) => any | undefined

Defined in: collection-adapters.ts:53

Wrap Map mutating methods to record changes and notify listeners.

Parameters

target

Map<any, any>

The Map instance

currentPath

string[]

The path to the Map

rootObject

object

The root object

deps

CollectionAdapterDeps

Dependencies (getBatchFrames)

method

string

The method name being accessed

Returns

(...args) => any | undefined

Wrapped method or undefined if not a mutating method


adaptSetMethod()

adaptSetMethod(target, currentPath, rootObject, deps, method): (...args) => any | undefined

Defined in: collection-adapters.ts:146

Wrap Set mutating methods to record changes and notify listeners.

Parameters

target

Set<any>

The Set instance

currentPath

string[]

The path to the Set

rootObject

object

The root object

deps

CollectionAdapterDeps

Dependencies (getBatchFrames)

method

string

The method name being accessed

Returns

(...args) => any | undefined

Wrapped method or undefined if not a mutating method

Released under the Apache-2.0 License.