GMP 0.4.0
Generative Metaprogramming library for C++
Loading...
Searching...
No Matches
gmp::reflectable Concept Reference

Constraint for aggregate types supported by the reflection helpers. More...

#include <meta.hpp>

Concept definition

template<typename T>
concept gmp::reflectable =
std::is_class_v<std::remove_cvref_t<T>> &&
std::is_aggregate_v<std::remove_cvref_t<T>> &&
Constraint for aggregate types supported by the reflection helpers.
Definition meta.hpp:496
#define GMP_MAX_SUPPORTED_FIELDS
Definition config.hpp:26
consteval auto enum_values()
Get all enumerator values of an enumeration type at compile-time.
Definition meta.hpp:193

Detailed Description

Note
C++20 cannot portably detect aggregate base classes or bit-fields. Types containing either may satisfy this concept, but reference-based helpers such as member_ref() and tie_members() do not support them.

Definition at line 496 of file meta.hpp.