Animate

Animate values and geometry over frames

Animate Action

nodes.geometry.AnimateAction(start=1, length=100)

GUI reference: Animate Action.

Parameters

Name Type Description Default
start InputInteger Start 1
length InputInteger Length 100

Inputs

Name Type Description
i.start IntegerSocket Start
i.length IntegerSocket Length

Outputs

Name Type Description
o.factor FloatSocket Factor
o.active BooleanSocket Whether the input Value is between (and including) the lower and upper bounds
o.stop IntegerSocket Stop

Animate Frames

nodes.geometry.AnimateFrames(
    atoms=None,
    selection=True,
    frames=None,
    smoother_step=False,
    interpolate=True,
    frame=0.0,
)

GUI reference: Animate Frames.

Parameters

Name Type Description Default
atoms InputGeometry Atomic geometry that contains vertices and edges None
selection InputBoolean Selection of atoms to apply this node to True
frames InputCollection Collection which holds the frames of the trajectory None
smoother_step InputBoolean Ease in and out of the individual frames if interpolating False
interpolate InputBoolean Whether to interpolate between frames of a trajectory or snap True
frame InputFloat Which frame to select from the collection. The fraction component of the float is how much to interpolate between the current and next frame 0.0

Inputs

Name Type Description
i.atoms GeometrySocket Atomic geometry that contains vertices and edges
i.selection BooleanSocket Selection of atoms to apply this node to
i.frames CollectionSocket Collection which holds the frames of the trajectory
i.smoother_step BooleanSocket Ease in and out of the individual frames if interpolating
i.interpolate BooleanSocket Whether to interpolate between frames of a trajectory or snap
i.frame FloatSocket Which frame to select from the collection. The fraction component of the float is how much to interpolate between the current and next frame

Outputs

Name Type Description
o.atoms GeometrySocket Atomic geometry with new positions based on the trajectory
o.all_frames GeometrySocket Each frame from the collection of coordinates is output in the a single mesh. They now contain an additional attribute frame_id to specify which structure they are from

Animate Peptide to Curve

nodes.geometry.AnimatePeptideToCurve(
    atoms=None,
    curve=None,
    offset=0.0,
    start=0.0,
    end=1.0,
    rotate=0.5,
    twist=1.0,
)

GUI reference: Animate Peptide to Curve.

Parameters

Name Type Description Default
atoms InputGeometry Atomic geometry that contains vertices and edges None
curve InputGeometry Curve None
offset InputFloat Offset 0.0
start InputFloat Start 0.0
end InputFloat End 1.0
rotate InputFloat Rotate 0.5
twist InputFloat Twist 1.0

Inputs

Name Type Description
i.atoms GeometrySocket Atomic geometry that contains vertices and edges
i.curve GeometrySocket Curve
i.offset FloatSocket Offset
i.start FloatSocket Start
i.end FloatSocket End
i.rotate FloatSocket Rotate
i.twist FloatSocket Twist

Outputs

Name Type Description
o.atoms GeometrySocket Atoms

Animate Trails

nodes.geometry.AnimateTrails(
    atoms=None,
    selection=True,
    trail_threshold='Unlimited',
    trail_curve_type='Poly',
    trail_frames=5,
    trail_radius=1.0,
    trail_resolution=6,
    trail_subdivisions=6,
    trail_cutoff=10.0,
    shade_smooth=True,
    material=None,
)

GUI reference: Animate Trails.

Parameters

Name Type Description Default
atoms InputGeometry Atomic geometry that contains vertices and edges None
selection InputBoolean Selection of atoms to apply this node to True
trail_threshold InputMenu | Literal['Unlimited', 'Threshold'] Trail Threshold 'Unlimited'
trail_curve_type InputMenu | Literal['Poly', 'Bezier'] Trail Curve Type 'Poly'
trail_frames InputInteger Number of previous frames from the trajectory to display 5
trail_radius InputFloat Trail Radius 1.0
trail_resolution InputInteger Tail radial resolution 6
trail_subdivisions InputInteger Trail Subdivisions 6
trail_cutoff InputFloat Threshold over which the spline is broken up 10.0
shade_smooth InputBoolean Apply smooth shading to the created geometry True
material InputMaterial Material to apply to the resulting geometry None

Inputs

Name Type Description
i.atoms GeometrySocket Atomic geometry that contains vertices and edges
i.selection BooleanSocket Selection of atoms to apply this node to
i.trail_threshold MenuSocket Trail Threshold
i.trail_curve_type MenuSocket Trail Curve Type
i.trail_frames IntegerSocket Number of previous frames from the trajectory to display
i.trail_radius FloatSocket Trail Radius
i.trail_resolution IntegerSocket Tail radial resolution
i.trail_subdivisions IntegerSocket Trail Subdivisions
i.trail_cutoff FloatSocket Threshold over which the spline is broken up
i.shade_smooth BooleanSocket Apply smooth shading to the created geometry
i.material MaterialSocket Material to apply to the resulting geometry

Outputs

Name Type Description
o.geometry GeometrySocket Geometry

Animate Value

nodes.geometry.AnimateValue(
    smoother_step=False,
    clamped=False,
    frame_start=1,
    frame_end=250,
    value_min=0.0,
    value_max=1.0,
)

GUI reference: Animate Value.

Parameters

Name Type Description Default
smoother_step InputBoolean Ease out and in from the min and max values False
clamped InputBoolean Whether to clamp the interpolated value to the max False
frame_start InputInteger Frame to start the animation on 1
frame_end InputInteger Frame to finish the animation on 250
value_min InputFloat Value to start animation from 0.0
value_max InputFloat Value to end animation at 1.0

Inputs

Name Type Description
i.smoother_step BooleanSocket Ease out and in from the min and max values
i.clamped BooleanSocket Whether to clamp the interpolated value to the max
i.frame_start IntegerSocket Frame to start the animation on
i.frame_end IntegerSocket Frame to finish the animation on
i.value_min FloatSocket Value to start animation from
i.value_max FloatSocket Value to end animation at

Outputs

Name Type Description
o.value FloatSocket Animated value that interpolates from min to max over frames

Animate Wiggle

nodes.geometry.AnimateWiggle(
    atoms=None,
    selection=True,
    b_factor=1.0,
    amplitude=1.0,
    amp_axis=1.0,
    amp_euler=0.4,
    speed=3.0,
    animate=0.0,
)

GUI reference: Animate Wiggle.

Parameters

Name Type Description Default
atoms InputGeometry Atomic geometry that contains vertices and edges None
selection InputBoolean Selection of atoms to apply this node to True
b_factor InputFloat Amount that b_factor changeds the amplitude of wiggling 1.0
amplitude InputFloat Overall amplitude of the wiggling 1.0
amp_axis InputFloat Aplitude for the rotation around the bond axes 1.0
amp_euler InputFloat Amplitude for applying euler rotations separate to the axis 0.4
speed InputFloat Speed at which the wiggle is applied, 3 will repeat 3 times 3.0
animate InputFloat Controls the animation of the wiggle, repeating every 1.00 0.0

Inputs

Name Type Description
i.atoms GeometrySocket Atomic geometry that contains vertices and edges
i.selection BooleanSocket Selection of atoms to apply this node to
i.b_factor FloatSocket Amount that b_factor changeds the amplitude of wiggling
i.amplitude FloatSocket Overall amplitude of the wiggling
i.amp_axis FloatSocket Aplitude for the rotation around the bond axes
i.amp_euler FloatSocket Amplitude for applying euler rotations separate to the axis
i.speed FloatSocket Speed at which the wiggle is applied, 3 will repeat 3 times
i.animate FloatSocket Controls the animation of the wiggle, repeating every 1.00

Outputs

Name Type Description
o.atoms GeometrySocket The animated atomic geometry