Attributes

Read attributes from structures

Atom ID

nodes.geometry.AtomID(index=0)

GUI reference: Atom ID.

Parameters

Name Type Description Default
index InputInteger Index 0

Inputs

Name Type Description
i.index IntegerSocket Index

Outputs

Name Type Description
o.atom_id IntegerSocket The atom_id attribute, read from geometry. Corresponds to the order of the atoms when they were read from the file

Atom Name

nodes.geometry.AtomName(index=0)

Geometry Nodes doesn’t currently support text attributes, so strings like atom names have to be first converted to integers and mapping to atom names back and forth. Definitions for the atom names are available on the GitHub page

GUI reference: Atom Name.

Parameters

Name Type Description Default
index InputInteger Index 0

Inputs

Name Type Description
i.index IntegerSocket Index

Outputs

Name Type Description
o.atom_name IntegerSocket The atom_name attribute read from the points, an integer representation of the atom names. Corresponds to CA and O in the file etc.

Atomic Number

nodes.geometry.AtomicNumber(index=0)

GUI reference: Atomic Number.

Parameters

Name Type Description Default
index InputInteger Index 0

Inputs

Name Type Description
i.index IntegerSocket Index

Outputs

Name Type Description
o.atomic_number IntegerSocket Read the atomic_number attribute from the geometry corresponding to elements

B Factor

nodes.geometry.BFactor(index=0)

GUI reference: B Factor.

Parameters

Name Type Description Default
index InputInteger Index 0

Inputs

Name Type Description
i.index IntegerSocket Index

Outputs

Name Type Description
o.b_factor FloatSocket b_factor

Chain ID

nodes.geometry.ChainID(index=0)

Integer representation of the Chain IDs that were present in the structure

GUI reference: Chain ID.

Parameters

Name Type Description Default
index InputInteger Index 0

Inputs

Name Type Description
i.index IntegerSocket Index

Outputs

Name Type Description
o.chain_id IntegerSocket The chain_id attribute read from the points, corresponding to the different chains that were read from the structure

Color

nodes.geometry.Color(index=0)

GUI reference: Color.

Parameters

Name Type Description Default
index InputInteger Index 0

Inputs

Name Type Description
i.index IntegerSocket Index

Outputs

Name Type Description
o.color ColorSocket Read the Color attribute from the geometry

Entity ID

nodes.geometry.EntityID(index=0)

The entity_id attribute read from the points, corresponding to the unique entities in the structure (that may appear several times as different chains)

GUI reference: Entity ID.

Parameters

Name Type Description Default
index InputInteger Index 0

Inputs

Name Type Description
i.index IntegerSocket Index

Outputs

Name Type Description
o.entity_id IntegerSocket The entity_id attribute read from the points, corresponding to the unique entities in the structure (that may appear several times as different chains)

Frame ID

nodes.geometry.FrameID(index=0)

Read the frame_id attribute, created when multiple frames from a trajectory are merged into a single structure

GUI reference: Frame ID.

Parameters

Name Type Description Default
index InputInteger Index 0

Inputs

Name Type Description
i.index IntegerSocket Index

Outputs

Name Type Description
o.frame_id IntegerSocket Read the frame_id attribute from the geometry

Mass

nodes.geometry.Mass(index=0)

GUI reference: Mass.

Parameters

Name Type Description Default
index InputInteger Index 0

Inputs

Name Type Description
i.index IntegerSocket Index

Outputs

Name Type Description
o.mass FloatSocket Read the mass attribute from the geometry

Residue ID

nodes.geometry.ResidueID(index=0)

GUI reference: Residue ID.

Parameters

Name Type Description Default
index InputInteger Index 0

Inputs

Name Type Description
i.index IntegerSocket Index

Outputs

Name Type Description
o.res_id IntegerSocket Read the res_id attribute from the geometry

Residue Name

nodes.geometry.ResidueName(index=0)

GUI reference: Residue Name.

Parameters

Name Type Description Default
index InputInteger Index 0

Inputs

Name Type Description
i.index IntegerSocket Index

Outputs

Name Type Description
o.res_name IntegerSocket Read the res_name attribute from the geometry

Secondary Structure

nodes.geometry.SecondaryStructure(index=0)

GUI reference: Secondary Structure.

Parameters

Name Type Description Default
index InputInteger Index 0

Inputs

Name Type Description
i.index IntegerSocket Index

Outputs

Name Type Description
o.sec_struct IntegerSocket sec_struct

URes ID

nodes.geometry.UResID(index=0)

GUI reference: URes ID.

Parameters

Name Type Description Default
index InputInteger Index 0

Inputs

Name Type Description
i.index IntegerSocket Index

Outputs

Name Type Description
o.ures_id IntegerSocket ures_id
o.size IntegerSocket The total of all of the values in the corresponding group

VDW Radii

nodes.geometry.VDWRadii(index=0)

GUI reference: VDW Radii.

Parameters

Name Type Description Default
index InputInteger Index 0

Inputs

Name Type Description
i.index IntegerSocket Index

Outputs

Name Type Description
o.vdw_radii FloatSocket Read the vdw_radii attribute from the geometry