Color

Set and manipulate the colors of atoms

Color Atomic Number

nodes.geometry.ColorAtomicNumber(atomic_number=6, color=None)

GUI reference: Color Atomic Number.

Parameters

Name Type Description Default
atomic_number InputInteger The atomic_number of to use the selected color for 6
color InputColor The color to use for the specified atomic_number None

Inputs

Name Type Description
i.atomic_number IntegerSocket The atomic_number of to use the selected color for
i.color ColorSocket The color to use for the specified atomic_number

Outputs

Name Type Description
o.color ColorSocket The generated color based on the node inputs

Color Attribute Map

nodes.geometry.ColorAttributeMap(
    color_space='Linear',
    name='b_factor',
    min=0.0,
    max=150.0,
    input_7=True,
    a=None,
    input_1=None,
    b=None,
)

GUI reference: Color Attribute Map.

Parameters

Name Type Description Default
color_space InputMenu | Literal['Linear', 'OKLab'] Color Space 'Linear'
name InputString Name of the attribute to map colors to 'b_factor'
min InputFloat Value for the attribute to be the minimum color 0.0
max InputFloat Value for the attribute to be the maxium color 150.0
input_7 InputBoolean Wheter to interpolate through the ‘Mid’ color. True
a InputColor Color mapped to the minimum value of the attribute None
input_1 InputColor Color mapped to the middle value of the attribute None
b InputColor Color mapped to the maximum value of the attribute None

Inputs

Name Type Description
i.color_space MenuSocket Color Space
i.name StringSocket Name of the attribute to map colors to
i.min FloatSocket Value for the attribute to be the minimum color
i.max FloatSocket Value for the attribute to be the maxium color
i.input_7 BooleanSocket Wheter to interpolate through the ‘Mid’ color.
i.a ColorSocket Color mapped to the minimum value of the attribute
i.input_1 ColorSocket Color mapped to the middle value of the attribute
i.b ColorSocket Color mapped to the maximum value of the attribute

Outputs

Name Type Description
o.color ColorSocket The mapped color value based on the attribute.

Color Attribute Random

nodes.geometry.ColorAttributeRandom(
    name='chain_id',
    colorspace='HSL',
    color_seed=0,
    hsl_saturation=0.6,
    hsl_lightness=0.6,
    oklab_luminance=0.9,
    oklab_chroma=0.2,
)

GUI reference: Color Attribute Random.

Parameters

Name Type Description Default
name InputString Attribute to base the random color generation on 'chain_id'
colorspace InputMenu | Literal['HSL', 'OKLab'] Colorspace 'HSL'
color_seed InputInteger Seed value for the random generation of the colors 0
hsl_saturation InputFloat Saturlation level for the random color 0.6
hsl_lightness InputFloat Lightness value for the generated random color 0.6
oklab_luminance InputFloat OKLab Luminance 0.9
oklab_chroma InputFloat OKLab Chroma 0.2

Inputs

Name Type Description
i.name StringSocket Attribute to base the random color generation on
i.colorspace MenuSocket Colorspace
i.color_seed IntegerSocket Seed value for the random generation of the colors
i.hsl_saturation FloatSocket Saturlation level for the random color
i.hsl_lightness FloatSocket Lightness value for the generated random color
i.oklab_luminance FloatSocket OKLab Luminance
i.oklab_chroma FloatSocket OKLab Chroma

Outputs

Name Type Description
o.color ColorSocket The randomly generated color based on the input attribute

Color Common

nodes.geometry.ColorCommon(
    hydrogen=None,
    carbon=None,
    nitrogen=None,
    oxygen=None,
    phosphorous=None,
    sulfur=None,
)

GUI reference: Color Common.

Parameters

Name Type Description Default
hydrogen InputColor Color to set for the element Hydrogen None
carbon InputColor Color to set for the element Carbon None
nitrogen InputColor Color to set for the element Nitrogen None
oxygen InputColor Color to set for the element Oxygen None
phosphorous InputColor Color to set for the element Phosphorous None
sulfur InputColor Color to set for the element Sulfur None

Inputs

Name Type Description
i.hydrogen ColorSocket Color to set for the element Hydrogen
i.carbon ColorSocket Color to set for the element Carbon
i.nitrogen ColorSocket Color to set for the element Nitrogen
i.oxygen ColorSocket Color to set for the element Oxygen
i.phosphorous ColorSocket Color to set for the element Phosphorous
i.sulfur ColorSocket Color to set for the element Sulfur

Outputs

Name Type Description
o.color ColorSocket The output colors for the common elements

Color Element

nodes.geometry.ColorElement(
    h=None,
    he=None,
    li=None,
    be=None,
    b=None,
    c=None,
    n=None,
    o=None,
    f=None,
    ne=None,
    na=None,
    mg=None,
    al=None,
    si=None,
    p=None,
    s=None,
    cl=None,
    ar=None,
    k=None,
    ca=None,
    sc=None,
    ti=None,
    v=None,
    cr=None,
    mn=None,
    fe=None,
    co=None,
    ni=None,
    cu=None,
    zn=None,
    ga=None,
    ge=None,
    as_=None,
    se=None,
    br=None,
    kr=None,
    rb=None,
    sr=None,
    y=None,
    zr=None,
    nb=None,
    mo=None,
    tc=None,
    ru=None,
    rh=None,
    pd=None,
    ag=None,
    cd=None,
    in_=None,
    sn=None,
    sb=None,
    te=None,
    i=None,
    xe=None,
    cs=None,
    ba=None,
    la=None,
    ce=None,
    pr=None,
    nd=None,
    pm=None,
    sm=None,
    eu=None,
    gd=None,
    tb=None,
    dy=None,
    ho=None,
    er=None,
    tm=None,
    yb=None,
    lu=None,
    hf=None,
    ta=None,
    w=None,
    re=None,
    os=None,
    ir=None,
    pt=None,
    au=None,
    hg=None,
)

GUI reference: Color Element.

Parameters

Name Type Description Default
h InputColor Set the color for the element H None
he InputColor Set the color for the element He None
li InputColor Set the color for the element Li None
be InputColor Set the color for the element Be None
b InputColor Set the color for the element B None
c InputColor Set the color for the element C None
n InputColor Set the color for the element N None
o InputColor Set the color for the element O None
f InputColor Set the color for the element F None
ne InputColor Set the color for the element Ne None
na InputColor Set the color for the element Na None
mg InputColor Set the color for the element Mg None
al InputColor Set the color for the element Al None
si InputColor Set the color for the element Si None
p InputColor Set the color for the element P None
s InputColor Set the color for the element S None
cl InputColor Set the color for the element Cl None
ar InputColor Set the color for the element Ar None
k InputColor Set the color for the element K None
ca InputColor Set the color for the element Ca None
sc InputColor Set the color for the element Sc None
ti InputColor Set the color for the element Ti None
v InputColor Set the color for the element V None
cr InputColor Set the color for the element Cr None
mn InputColor Set the color for the element Mn None
fe InputColor Set the color for the element Fe None
co InputColor Set the color for the element Co None
ni InputColor Set the color for the element Ni None
cu InputColor Set the color for the element Cu None
zn InputColor Set the color for the element Zn None
ga InputColor Set the color for the element Ga None
ge InputColor Set the color for the element Ge None
as_ InputColor Set the color for the element As None
se InputColor Set the color for the element Se None
br InputColor Set the color for the element Br None
kr InputColor Set the color for the element Kr None
rb InputColor Set the color for the element Rb None
sr InputColor Set the color for the element Sr None
y InputColor Set the color for the element Y None
zr InputColor Set the color for the element Zr None
nb InputColor Set the color for the element Nb None
mo InputColor Set the color for the element Mo None
tc InputColor Set the color for the element Tc None
ru InputColor Set the color for the element Ru None
rh InputColor Set the color for the element Rh None
pd InputColor Set the color for the element Pd None
ag InputColor Set the color for the element Ag None
cd InputColor Set the color for the element Cd None
in_ InputColor Set the color for the element In None
sn InputColor Set the color for the element Sn None
sb InputColor Set the color for the element Sb None
te InputColor Set the color for the element Te None
i InputColor Set the color for the element I None
xe InputColor Set the color for the element Xe None
cs InputColor Set the color for the element Cs None
ba InputColor Set the color for the element Ba None
la InputColor Set the color for the element La None
ce InputColor Set the color for the element Ce None
pr InputColor Set the color for the element Pr None
nd InputColor Set the color for the element Nd None
pm InputColor Set the color for the element Pm None
sm InputColor Set the color for the element Sm None
eu InputColor Set the color for the element Eu None
gd InputColor Set the color for the element Gd None
tb InputColor Set the color for the element Tb None
dy InputColor Set the color for the element Dy None
ho InputColor Set the color for the element Ho None
er InputColor Set the color for the element Er None
tm InputColor Set the color for the element Tm None
yb InputColor Set the color for the element Yb None
lu InputColor Set the color for the element Lu None
hf InputColor Set the color for the element Hf None
ta InputColor Set the color for the element Ta None
w InputColor Set the color for the element W None
re InputColor Set the color for the element Re None
os InputColor Set the color for the element Os None
ir InputColor Set the color for the element Ir None
pt InputColor Set the color for the element Pt None
au InputColor Set the color for the element Au None
hg InputColor Set the color for the element Hg None

Inputs

Name Type Description
i.h ColorSocket Set the color for the element H
i.he ColorSocket Set the color for the element He
i.li ColorSocket Set the color for the element Li
i.be ColorSocket Set the color for the element Be
i.b ColorSocket Set the color for the element B
i.c ColorSocket Set the color for the element C
i.n ColorSocket Set the color for the element N
i.o ColorSocket Set the color for the element O
i.f ColorSocket Set the color for the element F
i.ne ColorSocket Set the color for the element Ne
i.na ColorSocket Set the color for the element Na
i.mg ColorSocket Set the color for the element Mg
i.al ColorSocket Set the color for the element Al
i.si ColorSocket Set the color for the element Si
i.p ColorSocket Set the color for the element P
i.s ColorSocket Set the color for the element S
i.cl ColorSocket Set the color for the element Cl
i.ar ColorSocket Set the color for the element Ar
i.k ColorSocket Set the color for the element K
i.ca ColorSocket Set the color for the element Ca
i.sc ColorSocket Set the color for the element Sc
i.ti ColorSocket Set the color for the element Ti
i.v ColorSocket Set the color for the element V
i.cr ColorSocket Set the color for the element Cr
i.mn ColorSocket Set the color for the element Mn
i.fe ColorSocket Set the color for the element Fe
i.co ColorSocket Set the color for the element Co
i.ni ColorSocket Set the color for the element Ni
i.cu ColorSocket Set the color for the element Cu
i.zn ColorSocket Set the color for the element Zn
i.ga ColorSocket Set the color for the element Ga
i.ge ColorSocket Set the color for the element Ge
i.as_ ColorSocket Set the color for the element As
i.se ColorSocket Set the color for the element Se
i.br ColorSocket Set the color for the element Br
i.kr ColorSocket Set the color for the element Kr
i.rb ColorSocket Set the color for the element Rb
i.sr ColorSocket Set the color for the element Sr
i.y ColorSocket Set the color for the element Y
i.zr ColorSocket Set the color for the element Zr
i.nb ColorSocket Set the color for the element Nb
i.mo ColorSocket Set the color for the element Mo
i.tc ColorSocket Set the color for the element Tc
i.ru ColorSocket Set the color for the element Ru
i.rh ColorSocket Set the color for the element Rh
i.pd ColorSocket Set the color for the element Pd
i.ag ColorSocket Set the color for the element Ag
i.cd ColorSocket Set the color for the element Cd
i.in_ ColorSocket Set the color for the element In
i.sn ColorSocket Set the color for the element Sn
i.sb ColorSocket Set the color for the element Sb
i.te ColorSocket Set the color for the element Te
i.i ColorSocket Set the color for the element I
i.xe ColorSocket Set the color for the element Xe
i.cs ColorSocket Set the color for the element Cs
i.ba ColorSocket Set the color for the element Ba
i.la ColorSocket Set the color for the element La
i.ce ColorSocket Set the color for the element Ce
i.pr ColorSocket Set the color for the element Pr
i.nd ColorSocket Set the color for the element Nd
i.pm ColorSocket Set the color for the element Pm
i.sm ColorSocket Set the color for the element Sm
i.eu ColorSocket Set the color for the element Eu
i.gd ColorSocket Set the color for the element Gd
i.tb ColorSocket Set the color for the element Tb
i.dy ColorSocket Set the color for the element Dy
i.ho ColorSocket Set the color for the element Ho
i.er ColorSocket Set the color for the element Er
i.tm ColorSocket Set the color for the element Tm
i.yb ColorSocket Set the color for the element Yb
i.lu ColorSocket Set the color for the element Lu
i.hf ColorSocket Set the color for the element Hf
i.ta ColorSocket Set the color for the element Ta
i.w ColorSocket Set the color for the element W
i.re ColorSocket Set the color for the element Re
i.os ColorSocket Set the color for the element Os
i.ir ColorSocket Set the color for the element Ir
i.pt ColorSocket Set the color for the element Pt
i.au ColorSocket Set the color for the element Au
i.hg ColorSocket Set the color for the element Hg

Outputs

Name Type Description
o.color ColorSocket The selected colors based on the atomic_number

Color Goodsell

nodes.geometry.ColorGoodsell(color=None, factor=0.3, invert=False)

GUI reference: Color Goodsell.

Parameters

Name Type Description Default
color InputColor Color to apply ‘Goodsell’ style colors to None
factor InputFloat Amount to apply the ‘Goodsell Style’ coloring to 0.3
invert InputBoolean Whether to invert the darkening of the colors False

Inputs

Name Type Description
i.color ColorSocket Color to apply ‘Goodsell’ style colors to
i.factor FloatSocket Amount to apply the ‘Goodsell Style’ coloring to
i.invert BooleanSocket Whether to invert the darkening of the colors

Outputs

Name Type Description
o.color ColorSocket The generated color based on the node inputs

Color Mix Intermediate

nodes.geometry.ColorMixIntermediate(
    factor=0.5,
    menu='Linear',
    socket_1=False,
    a=None,
    socket_2=None,
    b=None,
)

GUI reference: Color Mix Intermediate.

Parameters

Name Type Description Default
factor InputFloat Factor 0.5
menu InputMenu | Literal['Linear', 'OKLab'] Menu 'Linear'
socket_1 InputBoolean Intermediate False
a InputColor A None
socket_2 InputColor Intermediate None
b InputColor B None

Inputs

Name Type Description
i.factor FloatSocket Factor
i.menu MenuSocket Menu
i.socket_1 BooleanSocket Intermediate
i.a ColorSocket A
i.socket_2 ColorSocket Intermediate
i.b ColorSocket B

Outputs

Name Type Description
o.output ColorSocket Output

Color OKLab Mix

nodes.geometry.ColorOKLabMix(factor=0.5, a=None, b=None)

GUI reference: Color OKLab Mix.

Parameters

Name Type Description Default
factor InputFloat Factor 0.5
a InputColor A None
b InputColor B None

Inputs

Name Type Description
i.factor FloatSocket Factor
i.a ColorSocket A
i.b ColorSocket B

Outputs

Name Type Description
o.result ColorSocket Result

Color OKLab Offset

nodes.geometry.ColorOKLabOffset(
    color=None,
    colorspace='OKLab',
    luminance=0.0,
    saturation=0.0,
    lightness=0.0,
    hue=0.0,
)

GUI reference: Color OKLab Offset.

Parameters

Name Type Description Default
color InputColor Color None
colorspace InputMenu | Literal['OKLab', 'HSL'] Colorspace 'OKLab'
luminance InputFloat Luminance 0.0
saturation InputFloat Saturation 0.0
lightness InputFloat Lightness 0.0
hue InputFloat Hue 0.0

Inputs

Name Type Description
i.color ColorSocket Color
i.colorspace MenuSocket Colorspace
i.luminance FloatSocket Luminance
i.saturation FloatSocket Saturation
i.lightness FloatSocket Lightness
i.hue FloatSocket Hue

Outputs

Name Type Description
o.color ColorSocket Color

Color pLDDT

nodes.geometry.ColorPLDDT(_50=None, _70=None, socket_3=None, socket_4=None)

GUI reference: Color pLDDT.

Parameters

Name Type Description Default
_50 InputColor Color for pLDTT < 50 None
_70 InputColor Color for 50 < pLDTT < 70 None
socket_3 InputColor Color for 70 < pLDTT < 90 None
socket_4 InputColor Color for 90 < pLDTT None

Inputs

Name Type Description
i._50 ColorSocket Color for pLDTT < 50
i._70 ColorSocket Color for 50 < pLDTT < 70
i.socket_3 ColorSocket Color for 70 < pLDTT < 90
i.socket_4 ColorSocket Color for 90 < pLDTT

Outputs

Name Type Description
o.color ColorSocket Assigned color based on the pLDTT score

Color Rainbow

nodes.geometry.ColorRainbow(
    factor='Chain',
    color_space='HSV',
    offset=0.0,
    hsl_saturation=0.8,
    hsl_value=0.8,
    oklab_luminance=0.94,
    oklab_chroma=0.2,
)

GUI reference: Color Rainbow.

Parameters

Name Type Description Default
factor InputMenu | Literal['Residue', 'Chain', 'Structure'] Factor 'Chain'
color_space InputMenu | Literal['HSV', 'OKLab'] Color Space 'HSV'
offset InputFloat Offset the starting hue of the rainbow colors. HSV is 0-1 for the entire rainbow, OKLab is -Pi to Pi for the rainbow. 0.0
hsl_saturation InputFloat The Saturation value of the rainbow colors 0.8
hsl_value InputFloat The Value value of the resulting rainbow colors 0.8
oklab_luminance InputFloat OKLab Luminance 0.94
oklab_chroma InputFloat OKLab Chroma 0.2

Inputs

Name Type Description
i.factor MenuSocket Factor
i.color_space MenuSocket Color Space
i.offset FloatSocket Offset the starting hue of the rainbow colors. HSV is 0-1 for the entire rainbow, OKLab is -Pi to Pi for the rainbow.
i.hsl_saturation FloatSocket The Saturation value of the rainbow colors
i.hsl_value FloatSocket The Value value of the resulting rainbow colors
i.oklab_luminance FloatSocket OKLab Luminance
i.oklab_chroma FloatSocket OKLab Chroma

Outputs

Name Type Description
o.color ColorSocket The generated color

Color Res Name

nodes.geometry.ColorResName(
    ala=None,
    arg=None,
    asn=None,
    asp=None,
    cys=None,
    glu=None,
    gln=None,
    gly=None,
    his=None,
    ile=None,
    leu=None,
    lys=None,
    met=None,
    phe=None,
    pro=None,
    ser=None,
    thr=None,
    trp=None,
    tyr=None,
    val=None,
    a=None,
    c=None,
    g=None,
    t=None,
    ra=None,
    rc=None,
    rg=None,
    ru=None,
)

GUI reference: Color Res Name.

Parameters

Name Type Description Default
ala InputColor Set the color for the residue ALA None
arg InputColor Set the color for the residue ARG None
asn InputColor Set the color for the residue ASN None
asp InputColor Set the color for the residue ASP None
cys InputColor Set the color for the residue CYS None
glu InputColor Set the color for the residue GLU None
gln InputColor Set the color for the residue GLN None
gly InputColor Set the color for the residue GLY None
his InputColor Set the color for the residue HIS None
ile InputColor Set the color for the residue ILE None
leu InputColor Set the color for the residue LEU None
lys InputColor Set the color for the residue LYS None
met InputColor Set the color for the residue MET None
phe InputColor Set the color for the residue PHE None
pro InputColor Set the color for the residue PRO None
ser InputColor Set the color for the residue SER None
thr InputColor Set the color for the residue THR None
trp InputColor Set the color for the residue TRP None
tyr InputColor Set the color for the residue TYR None
val InputColor Set the color for the residue VAL None
a InputColor Set the color for the residue A None
c InputColor Set the color for the residue C None
g InputColor Set the color for the residue G None
t InputColor Set the color for the residue T None
ra InputColor Set the color for the residue rA None
rc InputColor Set the color for the residue rC None
rg InputColor Set the color for the residue rG None
ru InputColor Set the color for the residue rU None

Inputs

Name Type Description
i.ala ColorSocket Set the color for the residue ALA
i.arg ColorSocket Set the color for the residue ARG
i.asn ColorSocket Set the color for the residue ASN
i.asp ColorSocket Set the color for the residue ASP
i.cys ColorSocket Set the color for the residue CYS
i.glu ColorSocket Set the color for the residue GLU
i.gln ColorSocket Set the color for the residue GLN
i.gly ColorSocket Set the color for the residue GLY
i.his ColorSocket Set the color for the residue HIS
i.ile ColorSocket Set the color for the residue ILE
i.leu ColorSocket Set the color for the residue LEU
i.lys ColorSocket Set the color for the residue LYS
i.met ColorSocket Set the color for the residue MET
i.phe ColorSocket Set the color for the residue PHE
i.pro ColorSocket Set the color for the residue PRO
i.ser ColorSocket Set the color for the residue SER
i.thr ColorSocket Set the color for the residue THR
i.trp ColorSocket Set the color for the residue TRP
i.tyr ColorSocket Set the color for the residue TYR
i.val ColorSocket Set the color for the residue VAL
i.a ColorSocket Set the color for the residue A
i.c ColorSocket Set the color for the residue C
i.g ColorSocket Set the color for the residue G
i.t ColorSocket Set the color for the residue T
i.ra ColorSocket Set the color for the residue rA
i.rc ColorSocket Set the color for the residue rC
i.rg ColorSocket Set the color for the residue rG
i.ru ColorSocket Set the color for the residue rU

Outputs

Name Type Description
o.color ColorSocket Color

Color Secondary Structure

nodes.geometry.ColorSecondaryStructure(
    helix=None,
    sheet=None,
    loop=None,
    other=None,
)

GUI reference: Color Secondary Structure.

Parameters

Name Type Description Default
helix InputColor Color to set for alpha helices None
sheet InputColor Color to set for beta-sheets None
loop InputColor Color to set for loops in the structure None
other InputColor Other None

Inputs

Name Type Description
i.helix ColorSocket Color to set for alpha helices
i.sheet ColorSocket Color to set for beta-sheets
i.loop ColorSocket Color to set for loops in the structure
i.other ColorSocket Other

Outputs

Name Type Description
o.color ColorSocket The colors based on secondary structure

Color to LCh

nodes.geometry.ColorToLCh(color=None)

GUI reference: Color to LCh.

Parameters

Name Type Description Default
color InputColor Color None

Inputs

Name Type Description
i.color ColorSocket Color

Outputs

Name Type Description
o.l FloatSocket L
o.c FloatSocket C
o.h FloatSocket h

LCh to Color

nodes.geometry.LChToColor(l=0.0, c=0.0, h=0.0)

GUI reference: LCh to Color.

Parameters

Name Type Description Default
l InputFloat L 0.0
c InputFloat C 0.0
h InputFloat h 0.0

Inputs

Name Type Description
i.l FloatSocket L
i.c FloatSocket C
i.h FloatSocket h

Outputs

Name Type Description
o.color ColorSocket Color

Random Color

nodes.geometry.RandomColor(
    id=0,
    color_seed=0,
    colorspace='HSL',
    hsl_saturation=0.6,
    hsl_lightness=0.6,
    oklab_luminance=0.9,
    oklab_chroma=0.2,
)

GUI reference: Random Color.

Parameters

Name Type Description Default
id InputInteger ID 0
color_seed InputInteger Seed value for the random generation of the colors 0
colorspace InputMenu | Literal['HSL', 'OKLab'] Colorspace 'HSL'
hsl_saturation InputFloat Saturlation level for the random color 0.6
hsl_lightness InputFloat Lightness value for the generated random color 0.6
oklab_luminance InputFloat OKLab Luminance 0.9
oklab_chroma InputFloat OKLab Chroma 0.2

Inputs

Name Type Description
i.id IntegerSocket ID
i.color_seed IntegerSocket Seed value for the random generation of the colors
i.colorspace MenuSocket Colorspace
i.hsl_saturation FloatSocket Saturlation level for the random color
i.hsl_lightness FloatSocket Lightness value for the generated random color
i.oklab_luminance FloatSocket OKLab Luminance
i.oklab_chroma FloatSocket OKLab Chroma

Outputs

Name Type Description
o.color ColorSocket Color

Set Color

nodes.geometry.SetColor(atoms=None, selection=True, color=None)

GUI reference: Set Color.

Parameters

Name Type Description Default
atoms InputGeometry Atomic geometry that contains vertices and edges None
selection InputBoolean Selection of atoms to apply this node to True
color InputColor Color to apply to the selected atoms None

Inputs

Name Type Description
i.atoms GeometrySocket Atomic geometry that contains vertices and edges
i.selection BooleanSocket Selection of atoms to apply this node to
i.color ColorSocket Color to apply to the selected atoms

Outputs

Name Type Description
o.atoms GeometrySocket Atomic geometry with an updated Color attribute

MN Color

nodes.shader.MNColor()

GUI reference: MN Color.

Outputs

Name Type Description
o.color ColorSocket Color
o.alpha FloatSocket Alpha