Density

Work with volumetric density data

Density Style ISO Surface

nodes.geometry.DensityStyleISOSurface(
    volume=None,
    visible=True,
    threshold=0.009593,
    show_contours=False,
    only_contours=False,
    contour_thickness=0.1,
    contour_color=None,
    slice_width=None,
    slice_center=None,
    negative_color=None,
    positive_color=None,
    shade_smooth=True,
    material=None,
)

GUI reference: Density Style ISO Surface.

Parameters

Name Type Description Default
volume InputGeometry Input geometry None
visible InputBoolean Visibility of style True
threshold InputFloat ISO value 0.009593
show_contours InputBoolean Whether to show surface contours False
only_contours InputBoolean Only show contour edges False
contour_thickness InputFloat Thickness of the contour edges 0.1
contour_color InputColor Color of contour edges None
slice_width InputVector 1 None
slice_center InputVector Slice Center None
negative_color InputColor Color for negative ISO values None
positive_color InputColor Color for positive ISO values None
shade_smooth InputBoolean Use smooth shading for surface True
material InputMaterial Material to use for this surface None

Inputs

Name Type Description
i.volume GeometrySocket Input geometry
i.visible BooleanSocket Visibility of style
i.threshold FloatSocket ISO value
i.show_contours BooleanSocket Whether to show surface contours
i.only_contours BooleanSocket Only show contour edges
i.contour_thickness FloatSocket Thickness of the contour edges
i.contour_color ColorSocket Color of contour edges
i.slice_width VectorSocket 1
i.slice_center VectorSocket Slice Center
i.negative_color ColorSocket Color for negative ISO values
i.positive_color ColorSocket Color for positive ISO values
i.shade_smooth BooleanSocket Use smooth shading for surface
i.material MaterialSocket Material to use for this surface

Outputs

Name Type Description
o.geometry GeometrySocket ISO surface geometry output

Density Style Surface

nodes.geometry.DensityStyleSurface(
    volume=None,
    threshold=0.8,
    shade_smooth=True,
    hide_dust=0.0,
    color=None,
    material=None,
)

GUI reference: Density Style Surface.

Parameters

Name Type Description Default
volume InputGeometry Volume None
threshold InputFloat Threshold 0.8
shade_smooth InputBoolean Apply smooth shading to the created geometry True
hide_dust InputFloat Hide Dust 0.0
color InputColor Color None
material InputMaterial Material to apply to the resulting geometry None

Inputs

Name Type Description
i.volume GeometrySocket Volume
i.threshold FloatSocket Threshold
i.shade_smooth BooleanSocket Apply smooth shading to the created geometry
i.hide_dust FloatSocket Hide Dust
i.color ColorSocket Color
i.material MaterialSocket Material to apply to the resulting geometry

Outputs

Name Type Description
o.geometry GeometrySocket The generated geometry for the style node group

Density Style Wire

nodes.geometry.DensityStyleWire(
    volume=None,
    threshold=0.8,
    hide_dust=20.0,
    wire_radius=1.0,
    wire_resolution=3,
    color=None,
    material=None,
)

GUI reference: Density Style Wire.

Parameters

Name Type Description Default
volume InputGeometry Volume None
threshold InputFloat Threshold 0.8
hide_dust InputFloat Hide Dust 20.0
wire_radius InputFloat Radius of the created wire (in relative nm) 1.0
wire_resolution InputInteger Wire Resolution 3
color InputColor Color None
material InputMaterial Material to apply to the resulting geometry None

Inputs

Name Type Description
i.volume GeometrySocket Volume
i.threshold FloatSocket Threshold
i.hide_dust FloatSocket Hide Dust
i.wire_radius FloatSocket Radius of the created wire (in relative nm)
i.wire_resolution IntegerSocket Wire Resolution
i.color ColorSocket Color
i.material MaterialSocket Material to apply to the resulting geometry

Outputs

Name Type Description
o.geometry GeometrySocket The generated geometry for the style node group