DNA

Nodes for working with oxDNA and other DNA models

DNA From Curve

nodes.geometry.DNAFromCurve(
    curves=None,
    base_resolution=0,
    menu='Static',
    wind=1.0,
    base_instance='Instance',
)

GUI reference: DNA From Curve.

Parameters

Name Type Description Default
curves InputGeometry Curves None
base_resolution InputInteger Base Resolution 0
menu InputMenu | Literal['Static', 'Simulate'] Menu 'Static'
wind InputFloat Wind 1.0
base_instance InputMenu | Literal['Instance', 'Realize'] Base Instance 'Instance'

Inputs

Name Type Description
i.curves GeometrySocket Curves
i.base_resolution IntegerSocket Base Resolution
i.menu MenuSocket Menu
i.wind FloatSocket Wind
i.base_instance MenuSocket Base Instance

Outputs

Name Type Description
o.geometry GeometrySocket Geometry

oxDNA Realize Vectors

nodes.geometry.OxDNARealizeVectors(atoms=None)

GUI reference: oxDNA Realize Vectors.

Parameters

Name Type Description Default
atoms InputGeometry Geometry to duplicate elements of None

Inputs

Name Type Description
i.atoms GeometrySocket Geometry to duplicate elements of

Outputs

Name Type Description
o.geometry GeometrySocket Geometry

oxDNA Recover Vectors

nodes.geometry.OxDNARecoverVectors(geometry=None)

GUI reference: oxDNA Recover Vectors.

Parameters

Name Type Description Default
geometry InputGeometry Geometry None

Inputs

Name Type Description
i.geometry GeometrySocket Geometry

Outputs

Name Type Description
o.atoms GeometrySocket Atoms

oxDNA Style Ribbon

nodes.geometry.OxDNAStyleRibbon(
    atoms=None,
    selection=True,
    quality=2,
    backbone_shape='Arrows',
    backbone_radius=0.8,
    ball_radius=2.0,
    arrow_taper=0.3,
    base_shape='Sphere',
    base_geometry=None,
    base_scale=None,
    stem_scale=None,
    base_colors='Uniform',
    bases=None,
    a=None,
    c=None,
    g=None,
    t_u=None,
    strand_color='Color',
    strands=None,
    strand_1=None,
    strand_2=None,
    strand_3=None,
    strand_4=None,
    shade_smooth=True,
    material=None,
)

GUI reference: oxDNA Style Ribbon.

Parameters

Name Type Description Default
atoms InputGeometry Atoms None
selection InputBoolean Selection of atoms to apply this node to True
quality InputInteger Quality 2
backbone_shape InputMenu | Literal['Arrows', 'Curve'] Backbone Shape 'Arrows'
backbone_radius InputFloat Backbone Radius 0.8
ball_radius InputFloat Ball Radius 2.0
arrow_taper InputFloat Arrow Taper 0.3
base_shape InputMenu | Literal['Sphere', 'Cylinder', 'None'] Base Shape 'Sphere'
base_geometry InputGeometry Base Geometry None
base_scale InputVector Base Scale None
stem_scale InputVector Stem Scale None
base_colors InputMenu | Literal['Uniform', 'Base', 'Color'] Base Colors 'Uniform'
bases InputColor Bases None
a InputColor A None
c InputColor C None
g InputColor G None
t_u InputColor T / U None
strand_color InputMenu | Literal['Uniform', 'Strand', 'Color'] Strand Color 'Color'
strands InputColor Becomes the output value if it is chosen by the menu input None
strand_1 InputColor Strand 1 None
strand_2 InputColor Strand 2 None
strand_3 InputColor Strand 3 None
strand_4 InputColor Strand 4 None
shade_smooth InputBoolean Shade Smooth True
material InputMaterial Material to apply to the resulting geometry None

Inputs

Name Type Description
i.atoms GeometrySocket Atoms
i.selection BooleanSocket Selection of atoms to apply this node to
i.quality IntegerSocket Quality
i.backbone_shape MenuSocket Backbone Shape
i.backbone_radius FloatSocket Backbone Radius
i.ball_radius FloatSocket Ball Radius
i.arrow_taper FloatSocket Arrow Taper
i.base_shape MenuSocket Base Shape
i.base_geometry GeometrySocket Base Geometry
i.base_scale VectorSocket Base Scale
i.stem_scale VectorSocket Stem Scale
i.base_colors MenuSocket Base Colors
i.bases ColorSocket Bases
i.a ColorSocket A
i.c ColorSocket C
i.g ColorSocket G
i.t_u ColorSocket T / U
i.strand_color MenuSocket Strand Color
i.strands ColorSocket Becomes the output value if it is chosen by the menu input
i.strand_1 ColorSocket Strand 1
i.strand_2 ColorSocket Strand 2
i.strand_3 ColorSocket Strand 3
i.strand_4 ColorSocket Strand 4
i.shade_smooth BooleanSocket Shade Smooth
i.material MaterialSocket Material to apply to the resulting geometry

Outputs

Name Type Description
o.geometry GeometrySocket Geometry

oxDNA Vectors

nodes.geometry.OxDNAVectors(index=0)

GUI reference: oxDNA Vectors.

Parameters

Name Type Description Default
index InputInteger Index 0

Inputs

Name Type Description
i.index IntegerSocket Index

Outputs

Name Type Description
o.base_vector VectorSocket base_vector
o.base_normal VectorSocket base_normal
o.backbone_offset VectorSocket Backbone Offset
o.base_offset VectorSocket Base Offset
o.rotation RotationSocket Rotation