General

Assembly ID

nodes.geometry.AssemblyID(index=0)

Read the frame_id attribute, created when multiple frames from a trajectory are merged into a single structure

GUI reference: Assembly ID.

Parameters

Name Type Description Default
index InputInteger Index 0

Inputs

Name Type Description
i.index IntegerSocket Index

Outputs

Name Type Description
o.assembly_id IntegerSocket Read the frame_id attribute from the geometry

Edge Length

nodes.geometry.EdgeLength()

GUI reference: Edge Length.

Outputs

Name Type Description
o.length FloatSocket Length

Image ID

nodes.geometry.ImageID(index=0)

Read the frame_id attribute, created when multiple frames from a trajectory are merged into a single structure

GUI reference: Image ID.

Parameters

Name Type Description Default
index InputInteger Index 0

Inputs

Name Type Description
i.index IntegerSocket Index

Outputs

Name Type Description
o.image_id IntegerSocket Read the image_id attribute from the geometry

Symmetry ID

nodes.geometry.SymmetryID(index=0)

Read the frame_id attribute, created when multiple frames from a trajectory are merged into a single structure

GUI reference: Symmetry ID.

Parameters

Name Type Description Default
index InputInteger Index 0

Inputs

Name Type Description
i.index IntegerSocket Index

Outputs

Name Type Description
o.sym_id IntegerSocket Read the frame_id attribute from the geometry

Color AO

nodes.shader.ColorAO(
    color=None,
    menu='AO',
    ao_space='Local',
    distance=1.0,
    exponent=0.5,
)

GUI reference: Color AO.

Parameters

Name Type Description Default
color InputColor Color None
menu InputMenu | Literal['AO', 'None'] Menu 'AO'
ao_space InputMenu | Literal['Global', 'Local'] AO Space 'Local'
distance InputFloat Distance 1.0
exponent InputFloat Exponent 0.5

Inputs

Name Type Description
i.color ColorSocket Color
i.menu MenuSocket Menu
i.ao_space MenuSocket AO Space
i.distance FloatSocket Distance
i.exponent FloatSocket Exponent

Outputs

Name Type Description
o.result ColorSocket Result

Flat Internal

nodes.shader.FlatInternal(outline='Outline', threshold=0.8, thickness=0.15)

GUI reference: Flat Internal.

Parameters

Name Type Description Default
outline InputMenu | Literal['Outline', 'None'] Outline 'Outline'
threshold InputFloat Threshold 0.8
thickness InputFloat Thickness 0.15

Inputs

Name Type Description
i.outline MenuSocket Outline
i.threshold FloatSocket Threshold
i.thickness FloatSocket Thickness

Outputs

Name Type Description
o.emission ShaderSocket Emission