Materials

Shader node groups for the pre-built materials

Outline Mask

nodes.shader.OutlineMask(threshold=0.8, thickness=0.15)

GUI reference: Outline Mask.

Parameters

Name Type Description Default
threshold InputFloat Threshold 0.8
thickness InputFloat Thickness 0.15

Inputs

Name Type Description
i.threshold FloatSocket Threshold
i.thickness FloatSocket Thickness

Outputs

Name Type Description
o.outline FloatSocket Outline

Transparent Outline Internal

nodes.shader.TransparentOutlineInternal(
    transparency=0.9,
    menu='Transparent',
    outline_color=None,
)

GUI reference: Transparent Outline Internal.

Parameters

Name Type Description Default
transparency InputFloat Blend weight to use for mixing two shaders. At zero it uses the first shader entirely and at one the second shader 0.9
menu InputMenu | Literal['Transparent', 'Fresnel'] Menu 'Transparent'
outline_color InputColor Outline Color None

Inputs

Name Type Description
i.transparency FloatSocket Blend weight to use for mixing two shaders. At zero it uses the first shader entirely and at one the second shader
i.menu MenuSocket Menu
i.outline_color ColorSocket Outline Color

Outputs

Name Type Description
o.shader ShaderSocket Shader