Style

Generate geometry for the different molecular styles

Style Ball and Stick

nodes.geometry.StyleBallAndStick(
    atoms=None,
    selection=True,
    quality=2,
    sphere='Instance',
    scale=0.3,
    bond_split='Double',
    bond_scale=0.3,
    bond_find=False,
    bond_find_scale=1.0,
    shade_smooth=True,
    material=None,
)

GUI reference: Style Ball and Stick.

Parameters

Name Type Description Default
atoms InputGeometry Atomic geometry that contains vertices and edges None
selection InputBoolean Selection of atoms to apply this style to, discarding unselected points True
quality InputInteger A lower value results in less geometry, with a higher value meaning better looking but more dense geometry 2
sphere InputMenu | Literal['Point', 'Instance', 'Mesh'] Show spheres as a Point Cloud, Instances of a mesh Icosphere, or realised Mesh instances of an Icosphere. Point cloud is best for performance and should definitely be used if rendering in Cycles. 'Instance'
scale InputFloat Scale the vdw_radii attribute before setting the radius for the spheres 0.3
bond_split InputMenu | Literal['Single', 'Double'] Bond Split 'Double'
bond_scale InputFloat Set the radius for the generated bonds in Angstroms 0.3
bond_find InputBoolean Find possible bonds for the selected atoms based on a distance search. Unselected atoms maintain any bonds they already have. Bonds that are found are all treated as single bonds False
bond_find_scale InputFloat Scale the VDW radii of the atoms when searching for bonds 1.0
shade_smooth InputBoolean Apply smooth shading to the created geometry True
material InputMaterial Material to apply to the resulting geometry None

Inputs

Name Type Description
i.atoms GeometrySocket Atomic geometry that contains vertices and edges
i.selection BooleanSocket Selection of atoms to apply this style to, discarding unselected points
i.quality IntegerSocket A lower value results in less geometry, with a higher value meaning better looking but more dense geometry
i.sphere MenuSocket Show spheres as a Point Cloud, Instances of a mesh Icosphere, or realised Mesh instances of an Icosphere. Point cloud is best for performance and should definitely be used if rendering in Cycles.
i.scale FloatSocket Scale the vdw_radii attribute before setting the radius for the spheres
i.bond_split MenuSocket Bond Split
i.bond_scale FloatSocket Set the radius for the generated bonds in Angstroms
i.bond_find BooleanSocket Find possible bonds for the selected atoms based on a distance search. Unselected atoms maintain any bonds they already have. Bonds that are found are all treated as single bonds
i.bond_find_scale FloatSocket Scale the VDW radii of the atoms when searching for bonds
i.shade_smooth BooleanSocket Apply smooth shading to the created geometry
i.material MaterialSocket Material to apply to the resulting geometry

Outputs

Name Type Description
o.geometry GeometrySocket The generated geometry for the style node group

Style Cartoon

nodes.geometry.StyleCartoon(
    atoms=None,
    selection=True,
    quality=2,
    peptide_shape='Sharp',
    helix_shape='Spiral',
    helix_thickness=0.6,
    helix_width=2.2,
    sheet_arrows='Arrow',
    sheet_thickness=0.5,
    sheet_width=2.5,
    sheet_smoothing=0.5,
    loop_radius=0.4,
    backbone_shape='Cylinder',
    nucleic_width=3.0,
    nucleic_thickness=1.0,
    nucleic_radius=1.5,
    base_shape='Rectangle',
    base_scale_cylinder=None,
    base_scale_rectangle=None,
    color_blur=False,
    shade_smooth=True,
    material=None,
)

GUI reference: Style Cartoon.

Parameters

Name Type Description Default
atoms InputGeometry Atomic geometry that contains vertices and edges None
selection InputBoolean Selection of atoms to apply this style to, discarding unselected points True
quality InputInteger A lower value results in less geometry, with a higher value meaning better looking but more dense geometry 2
peptide_shape InputMenu | Literal['Sharp', 'Round'] Create rounded sheets and helices 'Sharp'
helix_shape InputMenu | Literal['Spiral', 'Cylinder'] Use cylinders for helices instead of ribbons 'Spiral'
helix_thickness InputFloat Thickness for the sheets and helices 0.6
helix_width InputFloat Width for the sheets and helices 2.2
sheet_arrows InputMenu | Literal['Arrow', 'Flat'] User arrows for sheets 'Arrow'
sheet_thickness InputFloat Sheet Thickness 0.5
sheet_width InputFloat Sheet Width 2.5
sheet_smoothing InputFloat Smoothing to apply to sheets 0.5
loop_radius InputFloat Radius of the loops for unstructure regions 0.4
backbone_shape InputMenu | Literal['Cylinder', 'Rectangle'] Backbone Shape 'Cylinder'
nucleic_width InputFloat Nucleic Width 3.0
nucleic_thickness InputFloat Nucleic Thickness 1.0
nucleic_radius InputFloat Nucleic Radius 1.5
base_shape InputMenu | Literal['Cylinder', 'Rectangle'] Base Shape 'Rectangle'
base_scale_cylinder InputVector Base Scale Cylinder None
base_scale_rectangle InputVector Base Scale Rectangle None
color_blur InputBoolean Interpolate between colors when enabled. When disabled the faces will take their color from their corresponding atom without interpolating False
shade_smooth InputBoolean Apply smooth shading to the created geometry True
material InputMaterial Material to apply to the resulting geometry None

Inputs

Name Type Description
i.atoms GeometrySocket Atomic geometry that contains vertices and edges
i.selection BooleanSocket Selection of atoms to apply this style to, discarding unselected points
i.quality IntegerSocket A lower value results in less geometry, with a higher value meaning better looking but more dense geometry
i.peptide_shape MenuSocket Create rounded sheets and helices
i.helix_shape MenuSocket Use cylinders for helices instead of ribbons
i.helix_thickness FloatSocket Thickness for the sheets and helices
i.helix_width FloatSocket Width for the sheets and helices
i.sheet_arrows MenuSocket User arrows for sheets
i.sheet_thickness FloatSocket Sheet Thickness
i.sheet_width FloatSocket Sheet Width
i.sheet_smoothing FloatSocket Smoothing to apply to sheets
i.loop_radius FloatSocket Radius of the loops for unstructure regions
i.backbone_shape MenuSocket Backbone Shape
i.nucleic_width FloatSocket Nucleic Width
i.nucleic_thickness FloatSocket Nucleic Thickness
i.nucleic_radius FloatSocket Nucleic Radius
i.base_shape MenuSocket Base Shape
i.base_scale_cylinder VectorSocket Base Scale Cylinder
i.base_scale_rectangle VectorSocket Base Scale Rectangle
i.color_blur BooleanSocket Interpolate between colors when enabled. When disabled the faces will take their color from their corresponding atom without interpolating
i.shade_smooth BooleanSocket Apply smooth shading to the created geometry
i.material MaterialSocket Material to apply to the resulting geometry

Outputs

Name Type Description
o.geometry GeometrySocket The generated geometry for the style node group

Style Ribbon

nodes.geometry.StyleRibbon(
    atoms=None,
    selection=True,
    quality=3,
    peptide_radius=1.6,
    backbone_smoothing=0.5,
    backbone_threshold=4.5,
    uv_map=False,
    u_component='Factor',
    nucleic_backbone_shape='Cicular',
    nucleic_backbone_radius=2.0,
    nucleic_backbone_width=4.0,
    nucleic_backbone_thickness=1.0,
    base_geometry=None,
    base_scale=None,
    base_resolution=4,
    base_realize=False,
    shade_smooth=True,
    material=None,
)

GUI reference: Style Ribbon.

Parameters

Name Type Description Default
atoms InputGeometry Atomic geometry that contains vertices and edges None
selection InputBoolean Selection of atoms to apply this style to, discarding unselected points True
quality InputInteger A lower value results in less geometry, with a higher value meaning better looking but more dense geometry 3
peptide_radius InputFloat Peptide Radius 1.6
backbone_smoothing InputFloat Smoothen the sheet ribbons such as beta-sheets 0.5
backbone_threshold InputFloat Distance (Angstroms) over which subsequent CA points are treated as a new chain 4.5
uv_map InputBoolean Compute and store the uv_map for the final protein ribbon geometry False
u_component InputMenu | Literal['Factor', 'Length'] Store either the ‘Length’ or the ‘Factor’ of the curve as the U component. 'Factor'
nucleic_backbone_shape InputMenu | Literal['Cicular', 'Rectangular'] Nucleic Backbone Shape 'Cicular'
nucleic_backbone_radius InputFloat Nucleic Backbone Radius 2.0
nucleic_backbone_width InputFloat Nucleic Backbone Width 4.0
nucleic_backbone_thickness InputFloat Nucleic Backbone Thickness 1.0
base_geometry InputGeometry Base Geometry None
base_scale InputVector Base Scale None
base_resolution InputInteger Base Resolution 4
base_realize InputBoolean Base Realize False
shade_smooth InputBoolean Apply smooth shading to the created geometry True
material InputMaterial Material to apply to the resulting geometry None

Inputs

Name Type Description
i.atoms GeometrySocket Atomic geometry that contains vertices and edges
i.selection BooleanSocket Selection of atoms to apply this style to, discarding unselected points
i.quality IntegerSocket A lower value results in less geometry, with a higher value meaning better looking but more dense geometry
i.peptide_radius FloatSocket Peptide Radius
i.backbone_smoothing FloatSocket Smoothen the sheet ribbons such as beta-sheets
i.backbone_threshold FloatSocket Distance (Angstroms) over which subsequent CA points are treated as a new chain
i.uv_map BooleanSocket Compute and store the uv_map for the final protein ribbon geometry
i.u_component MenuSocket Store either the ‘Length’ or the ‘Factor’ of the curve as the U component.
i.nucleic_backbone_shape MenuSocket Nucleic Backbone Shape
i.nucleic_backbone_radius FloatSocket Nucleic Backbone Radius
i.nucleic_backbone_width FloatSocket Nucleic Backbone Width
i.nucleic_backbone_thickness FloatSocket Nucleic Backbone Thickness
i.base_geometry GeometrySocket Base Geometry
i.base_scale VectorSocket Base Scale
i.base_resolution IntegerSocket Base Resolution
i.base_realize BooleanSocket Base Realize
i.shade_smooth BooleanSocket Apply smooth shading to the created geometry
i.material MaterialSocket Material to apply to the resulting geometry

Outputs

Name Type Description
o.geometry GeometrySocket The generated geometry for the style node group

Style Spheres

nodes.geometry.StyleSpheres(
    atoms=None,
    selection=True,
    sphere='Point',
    quality=2,
    scale=0.8,
    shade_smooth=True,
    material=None,
)

GUI reference: Style Spheres.

Parameters

Name Type Description Default
atoms InputGeometry Atomic geometry that contains vertices and edges None
selection InputBoolean Selection of atoms to apply this style to, discarding unselected points True
sphere InputMenu | Literal['Point', 'Instance', 'Mesh'] Show spheres as a Point Cloud, Instances of a mesh Icosphere, or realised Mesh instances of an Icosphere. Point cloud is best for performance and should definitely be used if rendering in Cycles. 'Point'
quality InputInteger Number of subdicisions when using Instances or Mesh to represent atoms 2
scale InputFloat Scale the vdw_radii of the atom when setting the radius of the spheres 0.8
shade_smooth InputBoolean Apply smooth shading when using Instances or Mesh True
material InputMaterial Material to apply to the resulting geometry None

Inputs

Name Type Description
i.atoms GeometrySocket Atomic geometry that contains vertices and edges
i.selection BooleanSocket Selection of atoms to apply this style to, discarding unselected points
i.sphere MenuSocket Show spheres as a Point Cloud, Instances of a mesh Icosphere, or realised Mesh instances of an Icosphere. Point cloud is best for performance and should definitely be used if rendering in Cycles.
i.quality IntegerSocket Number of subdicisions when using Instances or Mesh to represent atoms
i.scale FloatSocket Scale the vdw_radii of the atom when setting the radius of the spheres
i.shade_smooth BooleanSocket Apply smooth shading when using Instances or Mesh
i.material MaterialSocket Material to apply to the resulting geometry

Outputs

Name Type Description
o.geometry GeometrySocket The generated geometry for the style node group

Style Sticks

nodes.geometry.StyleSticks(
    atoms=None,
    selection=True,
    sphere='Instance',
    quality=3,
    scale=0.2,
    shade_smooth=True,
    material=None,
)

GUI reference: Style Sticks.

Parameters

Name Type Description Default
atoms InputGeometry Atomic geometry that contains vertices and edges None
selection InputBoolean Selection of atoms to apply this style to, discarding unselected points True
sphere InputMenu | Literal['Point', 'Instance', 'Mesh'] Show spheres as a Point Cloud, Instances of a mesh Icosphere, or realised Mesh instances of an Icosphere. Point cloud is best for performance and should definitely be used if rendering in Cycles. 'Instance'
quality InputInteger A lower value results in less geometry, with a higher value meaning better looking but more dense geometry 3
scale InputFloat Radius of the sticks in Angstroms 0.2
shade_smooth InputBoolean Apply smooth shading to the created geometry True
material InputMaterial Material to apply to the resulting geometry None

Inputs

Name Type Description
i.atoms GeometrySocket Atomic geometry that contains vertices and edges
i.selection BooleanSocket Selection of atoms to apply this style to, discarding unselected points
i.sphere MenuSocket Show spheres as a Point Cloud, Instances of a mesh Icosphere, or realised Mesh instances of an Icosphere. Point cloud is best for performance and should definitely be used if rendering in Cycles.
i.quality IntegerSocket A lower value results in less geometry, with a higher value meaning better looking but more dense geometry
i.scale FloatSocket Radius of the sticks in Angstroms
i.shade_smooth BooleanSocket Apply smooth shading to the created geometry
i.material MaterialSocket Material to apply to the resulting geometry

Outputs

Name Type Description
o.geometry GeometrySocket The generated geometry for the style node group

Style Surface

nodes.geometry.StyleSurface(
    atoms=None,
    selection=True,
    quality=3,
    scale=1.25,
    relax=5,
    offset=0.15,
    fillet=0,
    mean_width=1,
    mean_iterations=1,
    separate_by='chain_id',
    group_id=0,
    color_source='Alpha Carbon',
    color_blur=2,
    shade_smooth=True,
    material=None,
)

GUI reference: Style Surface.

Parameters

Name Type Description Default
atoms InputGeometry Atomic geometry that contains vertices and edges None
selection InputBoolean Selection of atoms to apply this style to, discarding unselected points True
quality InputInteger A lower value results in less geometry, with a higher value meaning better looking but more dense geometry 3
scale InputFloat Scale the VDW radii of the atoms when creating the surface 1.25
relax InputInteger Relax 5
offset InputFloat Object-space distance to offset the SDF surface 0.15
fillet InputInteger Number of iterations to apply the filter 0
mean_width InputInteger Filter kernel radius in voxels 1
mean_iterations InputInteger Number of iterations to apply the filter 1
separate_by InputMenu | Literal['chain_id', 'Group ID'] Separate By 'chain_id'
group_id InputInteger Group ID 0
color_source InputMenu | Literal['Alpha Carbon', 'Nearest'] Color Source 'Alpha Carbon'
color_blur InputInteger Interpolate between colors when enabled. When disabled the faces will take their color from their corresponding atom without interpolating 2
shade_smooth InputBoolean Apply smooth shading to the created geometry True
material InputMaterial Material to apply to the resulting geometry None

Inputs

Name Type Description
i.atoms GeometrySocket Atomic geometry that contains vertices and edges
i.selection BooleanSocket Selection of atoms to apply this style to, discarding unselected points
i.quality IntegerSocket A lower value results in less geometry, with a higher value meaning better looking but more dense geometry
i.scale FloatSocket Scale the VDW radii of the atoms when creating the surface
i.relax IntegerSocket Relax
i.offset FloatSocket Object-space distance to offset the SDF surface
i.fillet IntegerSocket Number of iterations to apply the filter
i.mean_width IntegerSocket Filter kernel radius in voxels
i.mean_iterations IntegerSocket Number of iterations to apply the filter
i.separate_by MenuSocket Separate By
i.group_id IntegerSocket Group ID
i.color_source MenuSocket Color Source
i.color_blur IntegerSocket Interpolate between colors when enabled. When disabled the faces will take their color from their corresponding atom without interpolating
i.shade_smooth BooleanSocket Apply smooth shading to the created geometry
i.material MaterialSocket Material to apply to the resulting geometry

Outputs

Name Type Description
o.geometry GeometrySocket The generated geometry for the style node group