Utilities / Attribute

Sample Mix Float

nodes.geometry.SampleMixFloat(a=None, b=None, value=0.0, factor=0.5, index=0)

Sample a float value from two different geometries and mix from A to B

GUI reference: Sample Mix Float.

Parameters

Name Type Description Default
a InputGeometry Geometry A to sample and mix from None
b InputGeometry Geometry B to sample and mix to None
value InputFloat Float field to sample and mix 0.0
factor InputFloat Amount to mix from A to B 0.5
index InputInteger Index on the geometries to sample from 0

Inputs

Name Type Description
i.a GeometrySocket Geometry A to sample and mix from
i.b GeometrySocket Geometry B to sample and mix to
i.value FloatSocket Float field to sample and mix
i.factor FloatSocket Amount to mix from A to B
i.index IntegerSocket Index on the geometries to sample from

Outputs

Name Type Description
o.value FloatSocket The final mixed float

Sample Mix Vector

nodes.geometry.SampleMixVector(
    a=None,
    b=None,
    position=None,
    factor=0.5,
    index=0,
)

GUI reference: Sample Mix Vector.

Parameters

Name Type Description Default
a InputGeometry Geometry A to sample and mix from None
b InputGeometry Geometry B to sample and mix to None
position InputVector The field to sample from each geometry, defaulting to Position None
factor InputFloat The amount to mix from A to B 0.5
index InputInteger Index on the geometries to sample from 0

Inputs

Name Type Description
i.a GeometrySocket Geometry A to sample and mix from
i.b GeometrySocket Geometry B to sample and mix to
i.position VectorSocket The field to sample from each geometry, defaulting to Position
i.factor FloatSocket The amount to mix from A to B
i.index IntegerSocket Index on the geometries to sample from

Outputs

Name Type Description
o.vector VectorSocket The final mixed vector

Sample Mixed Rotation

nodes.geometry.SampleMixedRotation(geometry=None, rotation=None, index=0.0)

GUI reference: Sample Mixed Rotation.

Parameters

Name Type Description Default
geometry InputGeometry The geometry to sample the values from None
rotation InputRotation The field to mix and evaluate on the sample geometry None
index InputFloat The index to sample the value from. The fractional component of the index is used to mix between values using Index Mix ... nodes 0.0

Inputs

Name Type Description
i.geometry GeometrySocket The geometry to sample the values from
i.rotation RotationSocket The field to mix and evaluate on the sample geometry
i.index FloatSocket The index to sample the value from. The fractional component of the index is used to mix between values using Index Mix ... nodes

Outputs

Name Type Description
o.rotation RotationSocket The evaluated and mixed field, sampled from the sample geometry at the given Index

Sample Mixed Vector

nodes.geometry.SampleMixedVector(geometry=None, vector=None, index=0.0)

GUI reference: Sample Mixed Vector.

Parameters

Name Type Description Default
geometry InputGeometry The geometry to sample the values from None
vector InputVector The field to mix and evaluate on the sample geometry None
index InputFloat The index to sample the value from. The fractional component of the index is used to mix between values using Index Mix ... nodes 0.0

Inputs

Name Type Description
i.geometry GeometrySocket The geometry to sample the values from
i.vector VectorSocket The field to mix and evaluate on the sample geometry
i.index FloatSocket The index to sample the value from. The fractional component of the index is used to mix between values using Index Mix ... nodes

Outputs

Name Type Description
o.vector VectorSocket The evaluated and mixed field, sampled from the sample geometry at the given Index

Sample Position

nodes.geometry.SamplePosition(geometry=None, position=None, index=0)

A convenience wrapper around the Sample Index and Position nodes

GUI reference: Sample Position.

Parameters

Name Type Description Default
geometry InputGeometry The geometry to sample the Position from None
position InputVector The Position field to sample the values from None
index InputInteger The Index at which to sample the Position field from 0

Inputs

Name Type Description
i.geometry GeometrySocket The geometry to sample the Position from
i.position VectorSocket The Position field to sample the values from
i.index IntegerSocket The Index at which to sample the Position field from

Outputs

Name Type Description
o.position VectorSocket The sampled Position field