Utilities / Boolean

Boolean AndOr

nodes.geometry.BooleanAndOr(and_=True, or_=False, boolean=True)

GUI reference: Boolean AndOr.

Parameters

Name Type Description Default
and_ InputBoolean The resulting selection must overlap with this input selection True
or_ InputBoolean The resulting selection can be calculated from this node or be from this input selection False
boolean InputBoolean Boolean True

Inputs

Name Type Description
i.and_ BooleanSocket The resulting selection must overlap with this input selection
i.or_ BooleanSocket The resulting selection can be calculated from this node or be from this input selection
i.boolean BooleanSocket Boolean

Outputs

Name Type Description
o.boolean BooleanSocket Boolean
o.inverted BooleanSocket The inverse of the calculated selection

Expand Boolean

nodes.geometry.ExpandBoolean(boolean=False, expand=0)

GUI reference: Expand Boolean.

Parameters

Name Type Description Default
boolean InputBoolean Boolean False
expand InputInteger Expand 0

Inputs

Name Type Description
i.boolean BooleanSocket Boolean
i.expand IntegerSocket Expand

Outputs

Name Type Description
o.boolean BooleanSocket Boolean