GMP 0.3.0
Generative Metaprogramming library for C++
Loading...
Searching...
No Matches
object_factory.hpp File Reference
#include <functional>
#include <map>
#include <memory>
#include <stdexcept>
#include <string>
#include <gmp/dp/singleton.hpp>
#include <gmp/macro/macro.hpp>

Go to the source code of this file.

Classes

class  gmp::object_factory< AbstractProduct, ConstructorArgs >
 A singleton-backed runtime factory that creates products by string key. More...
 
struct  gmp::object_factory< AbstractProduct, ConstructorArgs >::register_type< T >
 Register a concrete product type under a string key. More...
 

Namespaces

namespace  gmp
 

Macros

#define GMP_FACTORY_REGISTER_WITH_ARGS(AbstractProduct, ConstructorArgs, ConcreteProduct)
 
#define GMP_FACTORY_REGISTER_NO_ARGS(AbstractProduct, ConcreteProduct)
 
#define GMP_FACTORY_REGISTER(AbstractProduct, ConstructorArgs, ...)
 Register one or more concrete product types with an object factory.