omicverse.datasets.pancreas_cellrank

omicverse.datasets.pancreas_cellrank#

omicverse.datasets.pancreas_cellrank(url='https://github.com/theislab/scvelo_notebooks/raw/master/data/Pancreas/endocrinogenesis_day15.h5ad', filename='pancreas_cellrank.h5ad')[source]#

The pancreas cellrank dataset used in theislab/scvelo_notebooks.

This data consists of 13,913 genes across 2,930 cells.

Note: The previous figshare URL (files/25060877) returned a 2KB HTML error page instead of the dataset, causing an infinite redownload loop. Switched the default to the scvelo_notebooks GitHub raw URL, which is the upstream source that scvelo / cellrank also use.

Return type:

AnnData