seamless.buffer_class

Class for Seamless buffers.

Buffer

  • kind: class
  • signature: Buffer

Class for Seamless buffers.

Buffer.checksum

  • kind: method
  • signature: checksum(self)

Returns the buffer's Checksum object, which must have been calculated already

Buffer.content

  • kind: method
  • signature: content(self)

Return the buffer value

Buffer.decode

  • kind: method
  • signature: decode(self)

No docstring.

Buffer.decref

  • kind: method
  • signature: decref(self)

Decrement normal refcount in the buffer cache. If no refs remain (and no tempref), may be uncached.

Buffer.from_async

  • kind: method
  • signature: from_async(cls, value, celltype, *, use_cache, checksum)

Init from value, asynchronously

Buffer.get_checksum

  • kind: method
  • signature: get_checksum(self)

Returns the buffer's Checksum object, calculating it if needed

Buffer.get_checksum_async

  • kind: method
  • signature: get_checksum_async(self)

Returns the buffer's Checksum object, calculating it asynchronously if needed

Buffer.get_value

  • kind: method
  • signature: get_value(self, celltype)

Converts the buffer to a value. The checksum must have been computed already.

Buffer.get_value_async

  • kind: method
  • signature: get_value_async(self, celltype, *, copy)

Converts the buffer to a value. The checksum must have been computed already.

If copy=False, the value can be returned from cache. It must not be modified.

Buffer.incref

  • kind: method
  • signature: incref(self)

Increment normal refcount in the buffer cache.

Buffer.load

  • kind: method
  • signature: load(cls, filename)

Loads the buffer from a file

Buffer.save

  • kind: method
  • signature: save(self, filename)

Saves the buffer to a file

Buffer.tempref

  • kind: method
  • signature: tempref(self, interest, fade_factor, fade_interval, scratch)

Add or refresh a single tempref. Only one tempref allowed per checksum.

If scratch is True, keep the tempref scratch-only (no remote registration).

Buffer.write

  • kind: method
  • signature: write(self)

Write the buffer to remote server(s), if any have been configured Returns True if the write has succeeded.