GMP 0.3.0
Generative Metaprogramming library for C++
Loading...
Searching...
No Matches
gmp::any Struct Reference

A placeholder type implicitly convertible to any type. More...

#include <utility.hpp>

Public Member Functions

template<typename T >
 operator T () const
 

Detailed Description

any is primarily used in compile-time aggregate probing and other metaprogramming contexts where a value of arbitrary type is required.

Definition at line 48 of file utility.hpp.

Member Function Documentation

◆ operator T()

template<typename T >
gmp::any::operator T ( ) const

The documentation for this struct was generated from the following file: