GMP 0.3.0
Generative Metaprogramming library for C++
Loading...
Searching...
No Matches
gmp::constant_arg_t< auto > Struct Template Reference

Wrap a compile-time value as a distinct function argument type. More...

#include <utility.hpp>

Public Member Functions

 constant_arg_t ()=default
 

Detailed Description

template<auto>
struct gmp::constant_arg_t< auto >

constant_arg_t<V> is used to pass non-type template parameter values through overload sets while preserving them as part of the type.

Template Parameters
Thecompile-time value being wrapped.

Definition at line 30 of file utility.hpp.

Constructor & Destructor Documentation

◆ constant_arg_t()

template<auto >
gmp::constant_arg_t< auto >::constant_arg_t ( )
explicitdefault

The documentation for this struct was generated from the following file: