GMP 0.3.0
Generative Metaprogramming library for C++
Loading...
Searching...
No Matches
gmp::enum_traits< E > Struct Template Reference

Customize the reflection range or explicit values for an enumeration. More...

#include <meta.hpp>

Static Public Attributes

static constexpr int min
 
static constexpr int max
 

Detailed Description

template<typename E>
struct gmp::enum_traits< E >

enum_traits<E> provides customization points used by the compile-time enum reflection utilities. By default, enumerator scanning uses the range [-128, 127]. Users can specialize this trait directly or use GMP_ENUM_RANGE / GMP_ENUM_VALUES to define a narrower scan range or an explicit enumerator list.

Template Parameters
EThe enumeration type being customized.

Definition at line 39 of file meta.hpp.

Member Data Documentation

◆ max

template<typename E >
constexpr int gmp::enum_traits< E >::max
staticconstexpr

Definition at line 41 of file meta.hpp.

◆ min

template<typename E >
constexpr int gmp::enum_traits< E >::min
staticconstexpr

Definition at line 40 of file meta.hpp.


The documentation for this struct was generated from the following file: