GMP 0.3.0
Generative Metaprogramming library for C++
Loading...
Searching...
No Matches
gmp::pretty_type_name< T > Struct Template Reference

Format a type name for documentation-friendly display. More...

#include <type_name.hpp>

Public Member Functions

consteval auto operator() ()
 Get the formatted type name.
 

Detailed Description

template<typename T>
struct gmp::pretty_type_name< T >

The primary template forwards to type_name<T>(). Selected standard library types may provide specializations with shorter or more conventional names.

Template Parameters
TThe type to format.

Definition at line 72 of file type_name.hpp.

Member Function Documentation

◆ operator()()

template<typename T >
consteval auto gmp::pretty_type_name< T >::operator() ( )
inline
Returns
A compile-time string representing T.

Definition at line 78 of file type_name.hpp.

References gmp::enum_values().


The documentation for this struct was generated from the following file: