Skip to content

@arcmantle/chronicle / three-way-merge

three-way-merge

Functions

threeWayMerge()

threeWayMerge(root, proxy, incomingObject, resolutions?): MergeResult

Defined in: three-way-merge.ts:98

Perform a three-way merge: merge an incoming object with the current state, detecting conflicts when both have modified the same path from the base.

Parameters

root

object

The unwrapped root object being observed

proxy

object

The proxied version to apply changes through (for tracking)

incomingObject

object

The incoming object to merge

resolutions?

ConflictResolutions

Optional conflict resolutions

Returns

MergeResult

MergeResult with conflicts and applied count

Released under the Apache-2.0 License.