Enum StrokeStyle
- Namespace
- Rustaveli.Pdf
- Assembly
- Rustaveli.Pdf.dll
How a stroke is drawn — the stroke types of a page-layout application.
public enum StrokeStyle
Fields
Solid = 0One continuous line.
Double = 1Two lines, each the stroke's weight, a weight apart and centred on where one would be.
Dotted = 2Round dots, each as wide as the stroke.
Dashed = 3Dashes three times the stroke's weight, with gaps of twice it.
Wavy = 4A wave, as a spelling checker marks a word.