Class TableColumns
- Namespace
- Rustaveli.Pdf
- Assembly
- Rustaveli.Pdf.dll
Declares the columns of a table.
public sealed class TableColumns
- Inheritance
-
TableColumns
- Inherited Members
Methods
Fixed(float)
Adds a column of fixed width in points.
public void Fixed(float width)
Parameters
widthfloat
Share(float)
Adds a column that takes a share of the width the fixed columns leave, in proportion to its weight.
public void Share(float weight = 1)
Parameters
weightfloat