Class VectorExportOptions
- Namespace
- Rustaveli.Pdf
- Assembly
- Rustaveli.Pdf.Raster.dll
How a document is exported as vector pages: SVG, or XPS.
public sealed class VectorExportOptions
- Inheritance
-
VectorExportOptions
- Inherited Members
Properties
ImageResolution
The resolution images generated at their final size are generated at: 288 pixels an inch unless set.
public float ImageResolution { get; set; }
Property Value
RequireEveryGlyph
Whether every character must be found in some typeface; on, the export fails with MissingGlyphException naming those that are not.
public bool RequireEveryGlyph { get; set; }
Property Value
Typefaces
The typefaces text is set in. Shared when not set.
public TypefaceLibrary? Typefaces { get; set; }