accuracy_plot¶
Plot the accuracy of BEM Green’s function reconstruction as a function of minumum distance Rx_min. The Rx_min is the minimum distance between the dipole and response point, also the x_target_min in the MATLAB script. We showed this result in our paper. The alpha_value is manually created based on the data we got from verify_bem_fresnel.py for different Rx_min and wavelength. The plot is saved as calibration_distance.png.
Try to run this script: python -m mqed.BEM.accuracy_plot