enhancement¶
- mqed.utils.enhancement.compute_enhancement(p_donor, p_acceptor, g_total, g_vac)[source]¶
Computes the enhancement factor for Resonance Energy Transfer (RET) given donor and acceptor dipole orientations and Green’s functions.
- Parameters:
p_donot (np.ndarray) – Donor dipole orientation (3-element array).
p_acceptor (np.ndarray) – Acceptor dipole orientation (3-element array).
g_total (np.ndarray) – Total Green’s function array of shape (M, N, 3, 3).
g_vac (np.ndarray) – Vacuum Green’s function array of shape (M, N, 3, 3).
- Returns:
Enhancement factor array of shape (M, N). E_enhance_real (np.ndarray): Real part of field enhancement array of shape (M, N). E_enhance_imag (np.ndarray): Imaginary part of field enhancement array of shape (M, N).
- Return type:
gamma (np.ndarray)