hydra_local¶
Utilities for exposing shared and personal Hydra config trees together.
- mqed.utils.hydra_local.prepare_hydra_config_path(config_group: str, caller_file: str) str[source]¶
Return a merged Hydra config directory for one config group.
The returned directory contains the shared configs from
configs/<group>overlaid with any personal configs fromlocal/configs/<group>so a Hydra entrypoint can resolve both through a singleconfig_path.- Parameters:
config_group – Config subgroup such as
plotsorLindblad.caller_file –
__file__from the module that will pass the path into@hydra.main.
- Returns:
An absolute path to the merged config directory.
- Raises:
FileNotFoundError – If the shared config directory for
config_groupdoes not exist.