@arcmantle/chronicle / nameof
nameof
Type Aliases
Nameof()
Nameof<
T> = (m) =>any
Defined in: nameof.ts:27
Type Parameters
T
T
Parameters
m
T extends object ? T : any
Returns
any
Functions
nameof()
nameof<
T>(expression):string
Defined in: nameof.ts:33
Returns the dot-separated property path captured from the selector expression.
Type Parameters
T
T
Parameters
expression
(instance) => any
Returns
string
nameofSegments()
nameofSegments<
T>(expression):string[]
Defined in: nameof.ts:59
Returns a fresh array of path segments captured from the selector expression. The returned array is a new copy to avoid external mutations affecting internals.
Type Parameters
T
T
Parameters
expression
(instance) => any
Returns
string[]