Collection which holds the frames of the trajectory
None
smoother_step
InputBoolean
Ease in and out of the individual frames if interpolating
False
interpolate
InputBoolean
Whether to interpolate between frames of a trajectory or snap
True
frame
InputFloat
Which frame to select from the collection. The fraction component of the float is how much to interpolate between the current and next frame
0.0
Inputs
Name
Type
Description
i.atoms
GeometrySocket
Atomic geometry that contains vertices and edges
i.selection
BooleanSocket
Selection of atoms to apply this node to
i.frames
CollectionSocket
Collection which holds the frames of the trajectory
i.smoother_step
BooleanSocket
Ease in and out of the individual frames if interpolating
i.interpolate
BooleanSocket
Whether to interpolate between frames of a trajectory or snap
i.frame
FloatSocket
Which frame to select from the collection. The fraction component of the float is how much to interpolate between the current and next frame
Outputs
Name
Type
Description
o.atoms
GeometrySocket
Atomic geometry with new positions based on the trajectory
o.all_frames
GeometrySocket
Each frame from the collection of coordinates is output in the a single mesh. They now contain an additional attribute frame_id to specify which structure they are from