Curves
Create and manipulate curves
Break Curves
nodes.geometry.BreakCurves(curves= None , threshold= 0.5 )
GUI reference: Break Curves .
Parameters
curves
InputGeometry
Geometry to delete elements from
None
threshold
InputFloat
Threshold
0.5
Outputs
o.curves
GeometrySocket
Curves
o.original_index
IntegerSocket
Index of Spline before segments removed
Cumulative Length
nodes.geometry.CumulativeLength()
GUI reference: Cumulative Length .
Outputs
o.length
FloatSocket
The length along the current spline added to all previous spline lengths
Curve Custom Profile
nodes.geometry.CurveCustomProfile(
curve= None ,
subdivisions= 6 ,
profile_type= 'Custom Profile' ,
uv_map= False ,
u_component= 'Factor' ,
socket_6= None ,
profile_scale= None ,
profile_curve= None ,
profile_resolution= 4 ,
profile_radius= 1.0 ,
input_14= 0.785398 ,
)
GUI reference: Curve Custom Profile .
Parameters
curve
InputGeometry
Curve
None
subdivisions
InputInteger
Subdivisions
6
profile_type
| Literal ['Default Profile', 'Custom Profile']
Profile Type
'Custom Profile'
uv_map
InputBoolean
Compute and store the uv_map attribute on the Face Corner domain of the final mesh
False
u_component
| Literal ['Factor', 'Length']
U Component
'Factor'
socket_6
InputRotation
Profile Rotation
None
profile_scale
InputVector
Profile Scale
None
profile_curve
InputGeometry
Profile Curve
None
profile_resolution
InputInteger
Profile Resolution
4
profile_radius
InputFloat
Profile Radius
1.0
input_14
InputFloat
Profile Rotation
0.785398
Outputs
o.geometry
GeometrySocket
Geometry
Curve Endpoint Values
nodes.geometry.CurveEndpointValues(
start_size= 1 ,
start_value= 1 ,
other_value= 0 ,
end_size= 1 ,
end_value=- 1 ,
)
Output a different integer value for the endpoints of a curve and the middle of a curve
GUI reference: Curve Endpoint Values .
Parameters
start_size
InputInteger
The size of the starting points of the curve
1
start_value
InputInteger
The value to output for the starting points of the curve
1
other_value
InputInteger
The value for the points which aren’t part of the start or end points
0
end_size
InputInteger
The size of the end points
1
end_value
InputInteger
The value that is returned for the end points of the curve
-1
Outputs
o.value
IntegerSocket
The value for the point, determined by the inputs if it is in the start, end or ‘other’ region
o.start_selection
BooleanSocket
The n points at the start of a spline determined by Start Size
o.end_selection
BooleanSocket
The n points at the end of a spline determined by End Size
Curve Offset Dot
nodes.geometry.CurveOffsetDot(
normal= None ,
offset=- 1 ,
threshold_direction= 'Less Than' ,
threshold_cutoff=- 0.9 ,
rotation_axis= None ,
rotation_amount= 3.141593 ,
)
GUI reference: Curve Offset Dot .
Parameters
normal
InputVector
Normal
None
offset
InputInteger
Offset
-1
threshold_direction
| Literal ['Less Than', 'Greater Than']
Threshold Direction
'Less Than'
threshold_cutoff
InputFloat
Threshold Cutoff
-0.9
rotation_axis
InputVector
Rotation Axis
None
rotation_amount
InputFloat
Rotation Amount
3.141593
Outputs
o.thresholded
BooleanSocket
Thresholded
o.leading
IntegerSocket
Leading
o.rotation
RotationSocket
Rotation
Curve Rotation
nodes.geometry.CurveRotation(normal= None )
Computes the rotation of the point on the curve, by default using the Normal attribute and the Tangent axis
GUI reference: Curve Rotation .
Parameters
normal
InputVector
The default direction to use as the Secondary Axis / X axis when computing the rotation
None
Outputs
o.rotation
RotationSocket
The computed rotation for the point on the curve
Curve Vectors
nodes.geometry.CurveVectors()
GUI reference: Curve Vectors .
Outputs
o.normal
VectorSocket
The normal of the control point. Used for calculating the rotation for the point and when calculating Curve to Mesh
o.tangent
VectorSocket
The tangent of the point, which is calculated as the direction from the previous point to the next point
o.bitangent
VectorSocket
The cross product of the Normal and the Tangent
Offset Point Along Curve
nodes.geometry.OffsetPointAlongCurve(point_index= 0 , offset= 0.0 )
Offset along the current point’s curve, by a number of points. 1 offsets by a single point on the curve (regardless of how far away they are). 1.5 offsets to half way between Point Index + 1 and Point Index + 2, returning the Length and the Factor for this point on the curve
GUI reference: Offset Point Along Curve .
Parameters
point_index
InputInteger
The field to evaluate at the given Index + Offset on the point domain
0
offset
InputFloat
The offset to apply to the Index before evaluating the input field
0.0
Outputs
o.is_off_spline
BooleanSocket
The field evaluated at the offset Index value
o.factor
FloatSocket
The field evaluated at the offset Index value
o.length
FloatSocket
The field evaluated at the offset Index value
o.index_a
IntegerSocket
The field evaluated at the offset Index value
o.index_b
IntegerSocket
The field evaluated at the offset Index value