DNA
Nodes for working with oxDNA and other DNA models
DNA From Curve
nodes.geometry.DNAFromCurve(
curves=None,
base_resolution=0,
menu='Static',
wind=1.0,
base_instance='Instance',
)
GUI reference: DNA From Curve.
Parameters
| curves |
InputGeometry |
Curves |
None |
| base_resolution |
InputInteger |
Base Resolution |
0 |
| menu |
| Literal['Static', 'Simulate'] |
Menu |
'Static' |
| wind |
InputFloat |
Wind |
1.0 |
| base_instance |
| Literal['Instance', 'Realize'] |
Base Instance |
'Instance' |
Outputs
| o.geometry |
GeometrySocket |
Geometry |
oxDNA Realize Vectors
nodes.geometry.OxDNARealizeVectors(atoms=None)
GUI reference: oxDNA Realize Vectors.
Parameters
| atoms |
InputGeometry |
Geometry to duplicate elements of |
None |
Outputs
| o.geometry |
GeometrySocket |
Geometry |
oxDNA Recover Vectors
nodes.geometry.OxDNARecoverVectors(geometry=None)
GUI reference: oxDNA Recover Vectors.
Parameters
| geometry |
InputGeometry |
Geometry |
None |
Outputs
| o.atoms |
GeometrySocket |
Atoms |
oxDNA Style Ribbon
nodes.geometry.OxDNAStyleRibbon(
atoms=None,
selection=True,
quality=2,
backbone_shape='Arrows',
backbone_radius=0.8,
ball_radius=2.0,
arrow_taper=0.3,
base_shape='Sphere',
base_geometry=None,
base_scale=None,
stem_scale=None,
base_colors='Uniform',
bases=None,
a=None,
c=None,
g=None,
t_u=None,
strand_color='Color',
strands=None,
strand_1=None,
strand_2=None,
strand_3=None,
strand_4=None,
shade_smooth=True,
material=None,
)
GUI reference: oxDNA Style Ribbon.
Parameters
| atoms |
InputGeometry |
Atoms |
None |
| selection |
InputBoolean |
Selection of atoms to apply this node to |
True |
| quality |
InputInteger |
Quality |
2 |
| backbone_shape |
| Literal['Arrows', 'Curve'] |
Backbone Shape |
'Arrows' |
| backbone_radius |
InputFloat |
Backbone Radius |
0.8 |
| ball_radius |
InputFloat |
Ball Radius |
2.0 |
| arrow_taper |
InputFloat |
Arrow Taper |
0.3 |
| base_shape |
| Literal['Sphere', 'Cylinder', 'None'] |
Base Shape |
'Sphere' |
| base_geometry |
InputGeometry |
Base Geometry |
None |
| base_scale |
InputVector |
Base Scale |
None |
| stem_scale |
InputVector |
Stem Scale |
None |
| base_colors |
| Literal['Uniform', 'Base', 'Color'] |
Base Colors |
'Uniform' |
| bases |
InputColor |
Bases |
None |
| a |
InputColor |
A |
None |
| c |
InputColor |
C |
None |
| g |
InputColor |
G |
None |
| t_u |
InputColor |
T / U |
None |
| strand_color |
| Literal['Uniform', 'Strand', 'Color'] |
Strand Color |
'Color' |
| strands |
InputColor |
Becomes the output value if it is chosen by the menu input |
None |
| strand_1 |
InputColor |
Strand 1 |
None |
| strand_2 |
InputColor |
Strand 2 |
None |
| strand_3 |
InputColor |
Strand 3 |
None |
| strand_4 |
InputColor |
Strand 4 |
None |
| shade_smooth |
InputBoolean |
Shade Smooth |
True |
| material |
InputMaterial |
Material to apply to the resulting geometry |
None |
Outputs
| o.geometry |
GeometrySocket |
Geometry |
oxDNA Vectors
nodes.geometry.OxDNAVectors(index=0)
GUI reference: oxDNA Vectors.
Parameters
| index |
InputInteger |
Index |
0 |
Outputs
| o.base_vector |
VectorSocket |
base_vector |
| o.base_normal |
VectorSocket |
base_normal |
| o.backbone_offset |
VectorSocket |
Backbone Offset |
| o.base_offset |
VectorSocket |
Base Offset |
| o.rotation |
RotationSocket |
Rotation |