DNA

Nodes for working with oxDNA and other DNA models

DNA From Curve

nodes.geometry.DNAFromCurve(
    curves=None,
    base_resolution=0,
    socket_3='Static',
    wind=1.0,
    socket_5='Instance',
)

GUI reference: DNA From Curve.

Parameters

Name Type Description Default
curves InputGeometry Curves None
base_resolution InputInteger Base Resolution 0
socket_3 InputMenu | Literal['Static', 'Simulate'] Menu 'Static'
wind InputFloat Wind 1.0
socket_5 InputMenu | Literal['Instance', 'Realize'] Menu 'Instance'

Inputs

Name Type Description
i.curves GeometrySocket Curves
i.base_resolution IntegerSocket Base Resolution
i.socket_3 MenuSocket Menu
i.wind FloatSocket Wind
i.socket_5 MenuSocket Menu

Outputs

Name Type Description
o.geometry GeometrySocket Geometry

oxDNA Normal

nodes.geometry.OxDNANormal(index=0)

GUI reference: oxDNA Normal.

Parameters

Name Type Description Default
index InputInteger Index 0

Inputs

Name Type Description
i.index IntegerSocket Index

Outputs

Name Type Description
o.base_normal VectorSocket base_normal

oxDNA Offset

nodes.geometry.OxDNAOffset(index=0)

GUI reference: oxDNA Offset.

Parameters

Name Type Description Default
index InputInteger Index 0

Inputs

Name Type Description
i.index IntegerSocket Index

Outputs

Name Type Description
o.offset VectorSocket Offset

oxDNA Rotation

nodes.geometry.OxDNARotation(index=0)

GUI reference: oxDNA Rotation.

Parameters

Name Type Description Default
index InputInteger Index 0

Inputs

Name Type Description
i.index IntegerSocket Index

Outputs

Name Type Description
o.rotation RotationSocket Rotation

oxDNA Style Ribbon

nodes.geometry.OxDNAStyleRibbon(
    geometry=None,
    selection=True,
    backbone_resolution=6,
    backbone_subdivisions=1,
    backbone_radius=2.0,
    a=None,
    c=None,
    g=None,
    t_u=None,
    base_scale=None,
    shade_smooth=True,
    material=None,
)

GUI reference: oxDNA Style Ribbon.

Parameters

Name Type Description Default
geometry InputGeometry Geometry None
selection InputBoolean Selection of atoms to apply this node to True
backbone_resolution InputInteger Backbone Resolution 6
backbone_subdivisions InputInteger Backbone Subdivisions 1
backbone_radius InputFloat Backbone Radius 2.0
a InputColor A None
c InputColor C None
g InputColor G None
t_u InputColor T / U None
base_scale InputVector Base Scale None
shade_smooth InputBoolean Shade Smooth True
material InputMaterial Material to apply to the resulting geometry None

Inputs

Name Type Description
i.geometry GeometrySocket Geometry
i.selection BooleanSocket Selection of atoms to apply this node to
i.backbone_resolution IntegerSocket Backbone Resolution
i.backbone_subdivisions IntegerSocket Backbone Subdivisions
i.backbone_radius FloatSocket Backbone Radius
i.a ColorSocket A
i.c ColorSocket C
i.g ColorSocket G
i.t_u ColorSocket T / U
i.base_scale VectorSocket Base Scale
i.shade_smooth BooleanSocket Shade Smooth
i.material MaterialSocket Material to apply to the resulting geometry

Outputs

Name Type Description
o.geometry GeometrySocket Geometry

oxDNA Vector

nodes.geometry.OxDNAVector(index=0)

GUI reference: oxDNA Vector.

Parameters

Name Type Description Default
index InputInteger Index 0

Inputs

Name Type Description
i.index IntegerSocket Index

Outputs

Name Type Description
o.base_vector VectorSocket base_vector