Ensemble
Instance and manipulate ensembles and assemblies
Assembly Instance
nodes.geometry.AssemblyInstance(
geometry= None ,
selection= True ,
data_object= None ,
assembly_id= 1 ,
realize_all= False ,
position= 1.0 ,
rotation= 1.0 ,
)
GUI reference: Assembly Instance .
Parameters
geometry
InputGeometry
Geometry that is instanced on the points
None
selection
InputBoolean
Selection
True
data_object
InputObject
Data Object
None
assembly_id
InputInteger
Assembly ID
1
realize_all
InputBoolean
Realize all levels of nested instances for a top-level instances. Overrides the value of the Depth input
False
position
InputFloat
Amount of mixing between the A and B inputs
1.0
rotation
InputFloat
Amount of mixing between the A and B inputs
1.0
Outputs
o.instances
GeometrySocket
Instances
o.chain_id
IntegerSocket
chain_id
Ensemble Instance
nodes.geometry.EnsembleInstance(
points= None ,
selection= True ,
selection_type= 'Simple' ,
instances= None ,
fraction= 1.0 ,
as_points= True ,
point_radius= 0.1 ,
point_material= None ,
)
GUI reference: Ensemble Instance .
Parameters
points
InputGeometry
Points
None
selection
InputBoolean
Selection of atoms to apply this node to
True
selection_type
| Literal ['Simple', 'Precise']
Selection Type
'Simple'
instances
InputCollection
Instances
None
fraction
InputFloat
Fraction
1.0
as_points
InputBoolean
As Points
True
point_radius
InputFloat
Point Radius
0.1
point_material
InputMaterial
Point Material
None
Outputs
o.instances
GeometrySocket
Instances
Lattice Grid
nodes.geometry.LatticeGrid(a= None , b= None , c= None , x= 3 , y= 3 , z= 3 )
GUI reference: Lattice Grid .
Parameters
a
InputVector
A
None
b
InputVector
B
None
c
InputVector
C
None
x
InputInteger
Number of images along the a vector
3
y
InputInteger
Number of images along the b vector
3
z
InputInteger
Number of images along the c vector
3
Outputs
o.grid
GeometrySocket
Grid
Periodic Array
nodes.geometry.PeriodicArray(
geometry= None ,
update= True ,
a= 0.0 ,
b= 0.0 ,
c= 0.0 ,
alpha= 0.0 ,
beta= 0.0 ,
gamma= 0.0 ,
x= 3 ,
y= 3 ,
z= 3 ,
)
GUI reference: Periodic Array .
Parameters
geometry
InputGeometry
Geometry
None
update
InputBoolean
Update the box lengths and angles with the simulation
True
a
InputFloat
a
0.0
b
InputFloat
b
0.0
c
InputFloat
c
0.0
alpha
InputFloat
alpha
0.0
beta
InputFloat
beta
0.0
gamma
InputFloat
gamma
0.0
x
InputInteger
Number of images along the a vector
3
y
InputInteger
Number of images along the b vector
3
z
InputInteger
Number of images along the c vector
3
Outputs
o.instances
GeometrySocket
Instances
Periodic Box
nodes.geometry.PeriodicBox(
update= True ,
a= 0.0 ,
b= 0.0 ,
c= 0.0 ,
alpha= 0.0 ,
beta= 0.0 ,
gamma= 0.0 ,
)
GUI reference: Periodic Box .
Parameters
update
InputBoolean
Update the box lengths and angles with the simulation. This does not change anything directly inside of the node tree, but the mda.Universe that updates the positions will also update this node.
True
a
InputFloat
a
0.0
b
InputFloat
b
0.0
c
InputFloat
c
0.0
alpha
InputFloat
alpha
0.0
beta
InputFloat
beta
0.0
gamma
InputFloat
gamma
0.0
Outputs
o.a
VectorSocket
A
o.b
VectorSocket
B
o.c
VectorSocket
C
Periodic Image
nodes.geometry.PeriodicImage(
a= None ,
b= None ,
c= None ,
image_a= 0 ,
image_b= 0 ,
image_c= 0 ,
)
GUI reference: Periodic Image .
Parameters
a
InputVector
A
None
b
InputVector
B
None
c
InputVector
C
None
image_a
InputInteger
Image A
0
image_b
InputInteger
Image B
0
image_c
InputInteger
Image C
0
Outputs
o.points
GeometrySocket
Points
Rotation cisTEM
nodes.geometry.RotationCisTEM()
GUI reference: Rotation cisTEM .
Outputs
o.rotation
RotationSocket
Rotation
o.is_valid
BooleanSocket
Is Valid
Rotation RELION
nodes.geometry.RotationRELION()
GUI reference: Rotation RELION .
Outputs
o.rotation
RotationSocket
Rotation
o.is_valid
BooleanSocket
Is Valid
TEM Rotation
nodes.geometry.TEMRotation(
phi= 'rlnAngleRot' ,
theta= 'rlnAngleTilt' ,
psi= 'rlnAnglePsi' ,
)
GUI reference: TEM Rotation .
Parameters
phi
InputString
Phi
'rlnAngleRot'
theta
InputString
Theta
'rlnAngleTilt'
psi
InputString
Psi
'rlnAnglePsi'
Outputs
o.rotation
RotationSocket
The combined Rotation
o.boolean
BooleanSocket
Boolean