Assembly ID
nodes.geometry.AssemblyID(index=0)
Read the frame_id attribute, created when multiple frames from a trajectory are merged into a single structure
GUI reference: Assembly ID.
Parameters
| index |
InputInteger |
Index |
0 |
Outputs
| o.assembly_id |
IntegerSocket |
Read the frame_id attribute from the geometry |
Edge Length
nodes.geometry.EdgeLength()
GUI reference: Edge Length.
Outputs
| o.length |
FloatSocket |
Length |
Image ID
nodes.geometry.ImageID(index=0)
Read the frame_id attribute, created when multiple frames from a trajectory are merged into a single structure
GUI reference: Image ID.
Parameters
| index |
InputInteger |
Index |
0 |
Outputs
| o.image_id |
IntegerSocket |
Read the image_id attribute from the geometry |
Symmetry ID
nodes.geometry.SymmetryID(index=0)
Read the frame_id attribute, created when multiple frames from a trajectory are merged into a single structure
GUI reference: Symmetry ID.
Parameters
| index |
InputInteger |
Index |
0 |
Outputs
| o.sym_id |
IntegerSocket |
Read the frame_id attribute from the geometry |
Color AO
nodes.shader.ColorAO(
color=None,
menu='AO',
ao_space='Local',
distance=1.0,
exponent=0.5,
)
GUI reference: Color AO.
Parameters
| color |
InputColor |
Color |
None |
| menu |
| Literal['AO', 'None'] |
Menu |
'AO' |
| ao_space |
| Literal['Global', 'Local'] |
AO Space |
'Local' |
| distance |
InputFloat |
Distance |
1.0 |
| exponent |
InputFloat |
Exponent |
0.5 |
Outputs
| o.result |
ColorSocket |
Result |
Flat Internal
nodes.shader.FlatInternal(outline='Outline', threshold=0.8, thickness=0.15)
GUI reference: Flat Internal.
Parameters
| outline |
| Literal['Outline', 'None'] |
Outline |
'Outline' |
| threshold |
InputFloat |
Threshold |
0.8 |
| thickness |
InputFloat |
Thickness |
0.15 |
Outputs
| o.emission |
ShaderSocket |
Emission |