General

Assembly ID

nodes.geometry.AssemblyID(index=0)

Read the frame_id attribute, created when multiple frames from a trajectory are merged into a single structure

GUI reference: Assembly ID.

Parameters

Name Type Description Default
index InputInteger Index 0

Inputs

Name Type Description
i.index IntegerSocket Index

Outputs

Name Type Description
o.assembly_id IntegerSocket Read the frame_id attribute from the geometry

Symmetry ID

nodes.geometry.SymmetryID(index=0)

Read the frame_id attribute, created when multiple frames from a trajectory are merged into a single structure

GUI reference: Symmetry ID.

Parameters

Name Type Description Default
index InputInteger Index 0

Inputs

Name Type Description
i.index IntegerSocket Index

Outputs

Name Type Description
o.sym_id IntegerSocket Read the frame_id attribute from the geometry

Color AO

nodes.shader.ColorAO(color=None, menu='AO', distance=1.0, exponent=2.0)

GUI reference: Color AO.

Parameters

Name Type Description Default
color InputColor Color None
menu InputMenu | Literal['AO', 'None'] Menu 'AO'
distance InputFloat Distance 1.0
exponent InputFloat Exponent 2.0

Inputs

Name Type Description
i.color ColorSocket Color
i.menu MenuSocket Menu
i.distance FloatSocket Distance
i.exponent FloatSocket Exponent

Outputs

Name Type Description
o.result ColorSocket Result

Flat

nodes.shader.Flat(outline='Outline', threshold=0.8, thickness=0.15)

GUI reference: Flat.

Parameters

Name Type Description Default
outline InputMenu | Literal['Outline', 'None'] Outline 'Outline'
threshold InputFloat Threshold 0.8
thickness InputFloat Thickness 0.15

Inputs

Name Type Description
i.outline MenuSocket Outline
i.threshold FloatSocket Threshold
i.thickness FloatSocket Thickness

Outputs

Name Type Description
o.emission ShaderSocket Emission