Materials

Shader node groups for the pre-built materials

Outline Mask

nodes.shader.OutlineMask(threshold=0.8, thickness=0.15)

GUI reference: Outline Mask.

Parameters

Name Type Description Default
threshold InputFloat Threshold 0.8
thickness InputFloat Thickness 0.15

Inputs

Name Type Description
i.threshold FloatSocket Threshold
i.thickness FloatSocket Thickness

Outputs

Name Type Description
o.outline FloatSocket Outline

Transparent Outline

nodes.shader.TransparentOutline(
    alpha=0.95,
    menu='Transparent',
    outline_color=None,
    threshold=0.2,
    thickness=0.15,
)

GUI reference: Transparent Outline.

Parameters

Name Type Description Default
alpha InputFloat Blend weight to use for mixing two shaders. At zero it uses the first shader entirely and at one the second shader 0.95
menu InputMenu | Literal['Transparent', 'Outline'] Menu 'Transparent'
outline_color InputColor Outline Color None
threshold InputFloat Threshold 0.2
thickness InputFloat Thickness 0.15

Inputs

Name Type Description
i.alpha FloatSocket Blend weight to use for mixing two shaders. At zero it uses the first shader entirely and at one the second shader
i.menu MenuSocket Menu
i.outline_color ColorSocket Outline Color
i.threshold FloatSocket Threshold
i.thickness FloatSocket Thickness

Outputs

Name Type Description
o.shader ShaderSocket Shader