Select
Create boolean selections based on the atomic attributes
Is Alpha Carbon
nodes.geometry.IsAlphaCarbon(and_=True, or_=False)GUI reference: Is Alpha Carbon.
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| and_ | InputBoolean |
The resulting selection must overlap with this input selection | True |
| or_ | InputBoolean |
The resulting selection can be calculated from this node or be from this input selection | False |
Inputs
| Name | Type | Description |
|---|---|---|
| i.and_ | BooleanSocket |
The resulting selection must overlap with this input selection |
| i.or_ | BooleanSocket |
The resulting selection can be calculated from this node or be from this input selection |
Outputs
| Name | Type | Description |
|---|---|---|
| o.selection | BooleanSocket |
The calculated selection |
| o.inverted | BooleanSocket |
The inverse of the calculated selection |
Is Backbone
nodes.geometry.IsBackbone(and_=True, or_=False)GUI reference: Is Backbone.
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| and_ | InputBoolean |
The resulting selection must overlap with this input selection | True |
| or_ | InputBoolean |
The resulting selection can be calculated from this node or be from this input selection | False |
Inputs
| Name | Type | Description |
|---|---|---|
| i.and_ | BooleanSocket |
The resulting selection must overlap with this input selection |
| i.or_ | BooleanSocket |
The resulting selection can be calculated from this node or be from this input selection |
Outputs
| Name | Type | Description |
|---|---|---|
| o.selection | BooleanSocket |
The calculated selection |
| o.inverted | BooleanSocket |
The inverse of the calculated selection |
Is Backbone Edge
nodes.geometry.IsBackboneEdge()GUI reference: Is Backbone Edge.
Outputs
| Name | Type | Description |
|---|---|---|
| o.is_backbone_edge | BooleanSocket |
Is Backbone Edge |
Is Boundary Edge
nodes.geometry.IsBoundaryEdge(mask=True)GUI reference: Is Boundary Edge.
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| mask | InputBoolean |
Mask | True |
Inputs
| Name | Type | Description |
|---|---|---|
| i.mask | BooleanSocket |
Mask |
Outputs
| Name | Type | Description |
|---|---|---|
| o.selection | BooleanSocket |
The calculated selection |
Is Helix
nodes.geometry.IsHelix(and_=True, or_=False)GUI reference: Is Helix.
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| and_ | InputBoolean |
The resulting selection must overlap with this input selection | True |
| or_ | InputBoolean |
The resulting selection can be calculated from this node or be from this input selection | False |
Inputs
| Name | Type | Description |
|---|---|---|
| i.and_ | BooleanSocket |
The resulting selection must overlap with this input selection |
| i.or_ | BooleanSocket |
The resulting selection can be calculated from this node or be from this input selection |
Outputs
| Name | Type | Description |
|---|---|---|
| o.selection | BooleanSocket |
The calculated selection |
| o.inverted | BooleanSocket |
The inverse of the calculated selection |
Is Hydrogen
nodes.geometry.IsHydrogen(and_=True, or_=False)GUI reference: Is Hydrogen.
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| and_ | InputBoolean |
The resulting selection must overlap with this input selection | True |
| or_ | InputBoolean |
The resulting selection can be calculated from this node or be from this input selection | False |
Inputs
| Name | Type | Description |
|---|---|---|
| i.and_ | BooleanSocket |
The resulting selection must overlap with this input selection |
| i.or_ | BooleanSocket |
The resulting selection can be calculated from this node or be from this input selection |
Outputs
| Name | Type | Description |
|---|---|---|
| o.selection | BooleanSocket |
Computed selection that includes Hydrogen atoms |
| o.inverted | BooleanSocket |
The inverse of the calculated selection |
Is Lipid
nodes.geometry.IsLipid(and_=True, or_=False)GUI reference: Is Lipid.
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| and_ | InputBoolean |
The resulting selection must overlap with this input selection | True |
| or_ | InputBoolean |
The resulting selection can be calculated from this node or be from this input selection | False |
Inputs
| Name | Type | Description |
|---|---|---|
| i.and_ | BooleanSocket |
The resulting selection must overlap with this input selection |
| i.or_ | BooleanSocket |
The resulting selection can be calculated from this node or be from this input selection |
Outputs
| Name | Type | Description |
|---|---|---|
| o.selection | BooleanSocket |
The calculated selection |
| o.inverted | BooleanSocket |
The inverse of the calculated selection |
Is Loop
nodes.geometry.IsLoop(and_=True, or_=False)GUI reference: Is Loop.
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| and_ | InputBoolean |
The resulting selection must overlap with this input selection | True |
| or_ | InputBoolean |
The resulting selection can be calculated from this node or be from this input selection | False |
Inputs
| Name | Type | Description |
|---|---|---|
| i.and_ | BooleanSocket |
The resulting selection must overlap with this input selection |
| i.or_ | BooleanSocket |
The resulting selection can be calculated from this node or be from this input selection |
Outputs
| Name | Type | Description |
|---|---|---|
| o.selection | BooleanSocket |
The calculated selection |
| o.inverted | BooleanSocket |
The inverse of the calculated selection |
Is Nucleic
nodes.geometry.IsNucleic(and_=True, or_=False)GUI reference: Is Nucleic.
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| and_ | InputBoolean |
The resulting selection must overlap with this input selection | True |
| or_ | InputBoolean |
The resulting selection can be calculated from this node or be from this input selection | False |
Inputs
| Name | Type | Description |
|---|---|---|
| i.and_ | BooleanSocket |
The resulting selection must overlap with this input selection |
| i.or_ | BooleanSocket |
The resulting selection can be calculated from this node or be from this input selection |
Outputs
| Name | Type | Description |
|---|---|---|
| o.selection | BooleanSocket |
The calculated selection |
| o.inverted | BooleanSocket |
The inverse of the calculated selection |
Is Peptide
nodes.geometry.IsPeptide(and_=True, or_=False)GUI reference: Is Peptide.
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| and_ | InputBoolean |
The resulting selection must overlap with this input selection | True |
| or_ | InputBoolean |
The resulting selection can be calculated from this node or be from this input selection | False |
Inputs
| Name | Type | Description |
|---|---|---|
| i.and_ | BooleanSocket |
The resulting selection must overlap with this input selection |
| i.or_ | BooleanSocket |
The resulting selection can be calculated from this node or be from this input selection |
Outputs
| Name | Type | Description |
|---|---|---|
| o.selection | BooleanSocket |
The calculated selection |
| o.inverted | BooleanSocket |
The inverse of the calculated selection |
Is Sheet
nodes.geometry.IsSheet(and_=True, or_=False)GUI reference: Is Sheet.
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| and_ | InputBoolean |
The resulting selection must overlap with this input selection | True |
| or_ | InputBoolean |
The resulting selection can be calculated from this node or be from this input selection | False |
Inputs
| Name | Type | Description |
|---|---|---|
| i.and_ | BooleanSocket |
The resulting selection must overlap with this input selection |
| i.or_ | BooleanSocket |
The resulting selection can be calculated from this node or be from this input selection |
Outputs
| Name | Type | Description |
|---|---|---|
| o.selection | BooleanSocket |
The calculated selection |
| o.inverted | BooleanSocket |
The inverse of the calculated selection |
Is Side Chain
nodes.geometry.IsSideChain(and_=True, or_=False, include_ca=True)GUI reference: Is Side Chain.
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| and_ | InputBoolean |
The resulting selection must overlap with this input selection | True |
| or_ | InputBoolean |
The resulting selection can be calculated from this node or be from this input selection | False |
| include_ca | InputBoolean |
Include the alpha carbon as part of the side chain | True |
Inputs
| Name | Type | Description |
|---|---|---|
| i.and_ | BooleanSocket |
The resulting selection must overlap with this input selection |
| i.or_ | BooleanSocket |
The resulting selection can be calculated from this node or be from this input selection |
| i.include_ca | BooleanSocket |
Include the alpha carbon as part of the side chain |
Outputs
| Name | Type | Description |
|---|---|---|
| o.selection | BooleanSocket |
The calculated selection |
| o.inverted | BooleanSocket |
The inverse of the calculated selection |
Is Solvent
nodes.geometry.IsSolvent(and_=True, or_=False)GUI reference: Is Solvent.
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| and_ | InputBoolean |
The resulting selection must overlap with this input selection | True |
| or_ | InputBoolean |
The resulting selection can be calculated from this node or be from this input selection | False |
Inputs
| Name | Type | Description |
|---|---|---|
| i.and_ | BooleanSocket |
The resulting selection must overlap with this input selection |
| i.or_ | BooleanSocket |
The resulting selection can be calculated from this node or be from this input selection |
Outputs
| Name | Type | Description |
|---|---|---|
| o.selection | BooleanSocket |
The calculated selection |
| o.inverted | BooleanSocket |
The inverse of the calculated selection |
Menu Atom Name
nodes.geometry.MenuAtomName(atom_name='N')GUI reference: Menu Atom Name.
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| atom_name | InputMenu | Literal['N', 'CA', 'C', 'O', 'CB', 'CG', 'CG1', 'CG2', 'OG', 'OG1', 'SG', 'CD', 'CD1', 'CD2', 'ND1', 'ND2', 'OD1', 'OD2', 'SD', 'CE', 'CE1', 'CE2', 'CE3', 'NE', 'NE1', 'NE2', 'OE1', 'OE2', 'CH2', 'NH1', 'NH2', 'OH', 'CZ', 'CZ2', 'CZ3', 'NZ', 'OXT', 'P', 'O1P', 'OP1', 'OP2', 'O2P', 'O5', 'C5', 'C4', 'O4', 'C3', 'O3', 'C2', 'O2', 'C1', 'N1', 'N9', 'N3', 'C8', 'N7', 'C5', 'C6', 'N6', 'C2', 'C4', 'O6', 'N2', 'N4', 'O2', 'O4', 'C7'] |
Atom Name | 'N' |
Inputs
| Name | Type | Description |
|---|---|---|
| i.atom_name | MenuSocket |
Atom Name |
Outputs
| Name | Type | Description |
|---|---|---|
| o.socket_1 | IntegerSocket |
atom_name |
| o.selection | BooleanSocket |
Selection |
| o.socket_3 | StringSocket |
atom_name |
Select Atomic Number
nodes.geometry.SelectAtomicNumber(and_=True, or_=False, atomic_number=6)GUI reference: Select Atomic Number.
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| and_ | InputBoolean |
The resulting selection must overlap with this input selection | True |
| or_ | InputBoolean |
The resulting selection can be calculated from this node or be from this input selection | False |
| atomic_number | InputInteger |
Create a selection based on the inputted atomic number. | 6 |
Inputs
| Name | Type | Description |
|---|---|---|
| i.and_ | BooleanSocket |
The resulting selection must overlap with this input selection |
| i.or_ | BooleanSocket |
The resulting selection can be calculated from this node or be from this input selection |
| i.atomic_number | IntegerSocket |
Create a selection based on the inputted atomic number. |
Outputs
| Name | Type | Description |
|---|---|---|
| o.selection | BooleanSocket |
The calculated selection |
| o.inverted | BooleanSocket |
The inverse of the calculated selection |
Select Attribute
nodes.geometry.SelectAttribute(and_=True, or_=False, name='is_peptide')GUI reference: Select Attribute.
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| and_ | InputBoolean |
The resulting selection must overlap with this input selection | True |
| or_ | InputBoolean |
The resulting selection can be calculated from this node or be from this input selection | False |
| name | InputString |
Name | 'is_peptide' |
Inputs
| Name | Type | Description |
|---|---|---|
| i.and_ | BooleanSocket |
The resulting selection must overlap with this input selection |
| i.or_ | BooleanSocket |
The resulting selection can be calculated from this node or be from this input selection |
| i.name | StringSocket |
Name |
Outputs
| Name | Type | Description |
|---|---|---|
| o.selection | BooleanSocket |
The calculated selection |
| o.inverted | BooleanSocket |
The inverse of the calculated selection |
Select Bonded
nodes.geometry.SelectBonded(selection=False, depth=1)GUI reference: Select Bonded.
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| selection | InputBoolean |
Selection of atoms to apply this node to | False |
| depth | InputInteger |
Number of bonds to expand the selection by | 1 |
Inputs
| Name | Type | Description |
|---|---|---|
| i.selection | BooleanSocket |
Selection of atoms to apply this node to |
| i.depth | IntegerSocket |
Number of bonds to expand the selection by |
Outputs
| Name | Type | Description |
|---|---|---|
| o.selection | BooleanSocket |
The calculated selection |
| o.bonded | BooleanSocket |
Expanded Selection that excludes the original selection |
Select Cube
nodes.geometry.SelectCube(and_=True, or_=False, object=None)GUI reference: Select Cube.
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| and_ | InputBoolean |
The resulting selection must overlap with this input selection | True |
| or_ | InputBoolean |
The resulting selection can be calculated from this node or be from this input selection | False |
| object | InputObject |
The position, rotation and scale from this Object will be used for the distance calculation for the selection. By default an Empty object is used, but any object can be used in principle | None |
Inputs
| Name | Type | Description |
|---|---|---|
| i.and_ | BooleanSocket |
The resulting selection must overlap with this input selection |
| i.or_ | BooleanSocket |
The resulting selection can be calculated from this node or be from this input selection |
| i.object | ObjectSocket |
The position, rotation and scale from this Object will be used for the distance calculation for the selection. By default an Empty object is used, but any object can be used in principle |
Outputs
| Name | Type | Description |
|---|---|---|
| o.selection | BooleanSocket |
The calculated selection |
| o.inverted | BooleanSocket |
The inverse of the calculated selection |
Select Element
nodes.geometry.SelectElement(
and_=True,
or_=False,
h=False,
he=False,
li=False,
be=False,
b=False,
c=False,
n=False,
o=False,
f=False,
ne=False,
na=False,
mg=False,
al=False,
si=False,
p=False,
s=False,
cl=False,
ar=False,
k=False,
ca=False,
sc=False,
ti=False,
v=False,
cr=False,
mn=False,
fe=False,
co=False,
ni=False,
cu=False,
zn=False,
ga=False,
ge=False,
as_=False,
se=False,
br=False,
kr=False,
rb=False,
sr=False,
y=False,
zr=False,
nb=False,
mo=False,
tc=False,
ru=False,
rh=False,
pd=False,
ag=False,
cd=False,
in_=False,
sn=False,
sb=False,
te=False,
i=False,
xe=False,
cs=False,
ba=False,
la=False,
ce=False,
pr=False,
nd=False,
pm=False,
sm=False,
eu=False,
gd=False,
tb=False,
dy=False,
ho=False,
er=False,
tm=False,
yb=False,
lu=False,
hf=False,
ta=False,
w=False,
re=False,
os=False,
ir=False,
pt=False,
au=False,
hg=False,
)GUI reference: Select Element.
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| and_ | InputBoolean |
The resulting selection must overlap with this input selection | True |
| or_ | InputBoolean |
The resulting selection can be calculated from this node or be from this input selection | False |
| h | InputBoolean |
Select the element H | False |
| he | InputBoolean |
Select the element He | False |
| li | InputBoolean |
Select the element Li | False |
| be | InputBoolean |
Select the element Be | False |
| b | InputBoolean |
Select the element B | False |
| c | InputBoolean |
Select the element C | False |
| n | InputBoolean |
Select the element N | False |
| o | InputBoolean |
Select the element O | False |
| f | InputBoolean |
Select the element F | False |
| ne | InputBoolean |
Select the element Ne | False |
| na | InputBoolean |
Select the element Na | False |
| mg | InputBoolean |
Select the element Mg | False |
| al | InputBoolean |
Select the element Al | False |
| si | InputBoolean |
Select the element Si | False |
| p | InputBoolean |
Select the element P | False |
| s | InputBoolean |
Select the element S | False |
| cl | InputBoolean |
Select the element Cl | False |
| ar | InputBoolean |
Select the element Ar | False |
| k | InputBoolean |
Select the element K | False |
| ca | InputBoolean |
Select the element Ca | False |
| sc | InputBoolean |
Select the element Sc | False |
| ti | InputBoolean |
Select the element Ti | False |
| v | InputBoolean |
Select the element V | False |
| cr | InputBoolean |
Select the element Cr | False |
| mn | InputBoolean |
Select the element Mn | False |
| fe | InputBoolean |
Select the element Fe | False |
| co | InputBoolean |
Select the element Co | False |
| ni | InputBoolean |
Select the element Ni | False |
| cu | InputBoolean |
Select the element Cu | False |
| zn | InputBoolean |
Select the element Zn | False |
| ga | InputBoolean |
Select the element Ga | False |
| ge | InputBoolean |
Select the element Ge | False |
| as_ | InputBoolean |
Select the element As | False |
| se | InputBoolean |
Select the element Se | False |
| br | InputBoolean |
Select the element Br | False |
| kr | InputBoolean |
Select the element Kr | False |
| rb | InputBoolean |
Select the element Rb | False |
| sr | InputBoolean |
Select the element Sr | False |
| y | InputBoolean |
Select the element Y | False |
| zr | InputBoolean |
Select the element Zr | False |
| nb | InputBoolean |
Select the element Nb | False |
| mo | InputBoolean |
Select the element Mo | False |
| tc | InputBoolean |
Select the element Tc | False |
| ru | InputBoolean |
Select the element Ru | False |
| rh | InputBoolean |
Select the element Rh | False |
| pd | InputBoolean |
Select the element Pd | False |
| ag | InputBoolean |
Select the element Ag | False |
| cd | InputBoolean |
Select the element Cd | False |
| in_ | InputBoolean |
Select the element In | False |
| sn | InputBoolean |
Select the element Sn | False |
| sb | InputBoolean |
Select the element Sb | False |
| te | InputBoolean |
Select the element Te | False |
| i | InputBoolean |
Select the element I | False |
| xe | InputBoolean |
Select the element Xe | False |
| cs | InputBoolean |
Select the element Cs | False |
| ba | InputBoolean |
Select the element Ba | False |
| la | InputBoolean |
Select the element La | False |
| ce | InputBoolean |
Select the element Ce | False |
| pr | InputBoolean |
Select the element Pr | False |
| nd | InputBoolean |
Select the element Nd | False |
| pm | InputBoolean |
Select the element Pm | False |
| sm | InputBoolean |
Select the element Sm | False |
| eu | InputBoolean |
Select the element Eu | False |
| gd | InputBoolean |
Select the element Gd | False |
| tb | InputBoolean |
Select the element Tb | False |
| dy | InputBoolean |
Select the element Dy | False |
| ho | InputBoolean |
Select the element Ho | False |
| er | InputBoolean |
Select the element Er | False |
| tm | InputBoolean |
Select the element Tm | False |
| yb | InputBoolean |
Select the element Yb | False |
| lu | InputBoolean |
Select the element Lu | False |
| hf | InputBoolean |
Select the element Hf | False |
| ta | InputBoolean |
Select the element Ta | False |
| w | InputBoolean |
Select the element W | False |
| re | InputBoolean |
Select the element Re | False |
| os | InputBoolean |
Select the element Os | False |
| ir | InputBoolean |
Select the element Ir | False |
| pt | InputBoolean |
Select the element Pt | False |
| au | InputBoolean |
Select the element Au | False |
| hg | InputBoolean |
Select the element Hg | False |
Inputs
| Name | Type | Description |
|---|---|---|
| i.and_ | BooleanSocket |
The resulting selection must overlap with this input selection |
| i.or_ | BooleanSocket |
The resulting selection can be calculated from this node or be from this input selection |
| i.h | BooleanSocket |
Select the element H |
| i.he | BooleanSocket |
Select the element He |
| i.li | BooleanSocket |
Select the element Li |
| i.be | BooleanSocket |
Select the element Be |
| i.b | BooleanSocket |
Select the element B |
| i.c | BooleanSocket |
Select the element C |
| i.n | BooleanSocket |
Select the element N |
| i.o | BooleanSocket |
Select the element O |
| i.f | BooleanSocket |
Select the element F |
| i.ne | BooleanSocket |
Select the element Ne |
| i.na | BooleanSocket |
Select the element Na |
| i.mg | BooleanSocket |
Select the element Mg |
| i.al | BooleanSocket |
Select the element Al |
| i.si | BooleanSocket |
Select the element Si |
| i.p | BooleanSocket |
Select the element P |
| i.s | BooleanSocket |
Select the element S |
| i.cl | BooleanSocket |
Select the element Cl |
| i.ar | BooleanSocket |
Select the element Ar |
| i.k | BooleanSocket |
Select the element K |
| i.ca | BooleanSocket |
Select the element Ca |
| i.sc | BooleanSocket |
Select the element Sc |
| i.ti | BooleanSocket |
Select the element Ti |
| i.v | BooleanSocket |
Select the element V |
| i.cr | BooleanSocket |
Select the element Cr |
| i.mn | BooleanSocket |
Select the element Mn |
| i.fe | BooleanSocket |
Select the element Fe |
| i.co | BooleanSocket |
Select the element Co |
| i.ni | BooleanSocket |
Select the element Ni |
| i.cu | BooleanSocket |
Select the element Cu |
| i.zn | BooleanSocket |
Select the element Zn |
| i.ga | BooleanSocket |
Select the element Ga |
| i.ge | BooleanSocket |
Select the element Ge |
| i.as_ | BooleanSocket |
Select the element As |
| i.se | BooleanSocket |
Select the element Se |
| i.br | BooleanSocket |
Select the element Br |
| i.kr | BooleanSocket |
Select the element Kr |
| i.rb | BooleanSocket |
Select the element Rb |
| i.sr | BooleanSocket |
Select the element Sr |
| i.y | BooleanSocket |
Select the element Y |
| i.zr | BooleanSocket |
Select the element Zr |
| i.nb | BooleanSocket |
Select the element Nb |
| i.mo | BooleanSocket |
Select the element Mo |
| i.tc | BooleanSocket |
Select the element Tc |
| i.ru | BooleanSocket |
Select the element Ru |
| i.rh | BooleanSocket |
Select the element Rh |
| i.pd | BooleanSocket |
Select the element Pd |
| i.ag | BooleanSocket |
Select the element Ag |
| i.cd | BooleanSocket |
Select the element Cd |
| i.in_ | BooleanSocket |
Select the element In |
| i.sn | BooleanSocket |
Select the element Sn |
| i.sb | BooleanSocket |
Select the element Sb |
| i.te | BooleanSocket |
Select the element Te |
| i.i | BooleanSocket |
Select the element I |
| i.xe | BooleanSocket |
Select the element Xe |
| i.cs | BooleanSocket |
Select the element Cs |
| i.ba | BooleanSocket |
Select the element Ba |
| i.la | BooleanSocket |
Select the element La |
| i.ce | BooleanSocket |
Select the element Ce |
| i.pr | BooleanSocket |
Select the element Pr |
| i.nd | BooleanSocket |
Select the element Nd |
| i.pm | BooleanSocket |
Select the element Pm |
| i.sm | BooleanSocket |
Select the element Sm |
| i.eu | BooleanSocket |
Select the element Eu |
| i.gd | BooleanSocket |
Select the element Gd |
| i.tb | BooleanSocket |
Select the element Tb |
| i.dy | BooleanSocket |
Select the element Dy |
| i.ho | BooleanSocket |
Select the element Ho |
| i.er | BooleanSocket |
Select the element Er |
| i.tm | BooleanSocket |
Select the element Tm |
| i.yb | BooleanSocket |
Select the element Yb |
| i.lu | BooleanSocket |
Select the element Lu |
| i.hf | BooleanSocket |
Select the element Hf |
| i.ta | BooleanSocket |
Select the element Ta |
| i.w | BooleanSocket |
Select the element W |
| i.re | BooleanSocket |
Select the element Re |
| i.os | BooleanSocket |
Select the element Os |
| i.ir | BooleanSocket |
Select the element Ir |
| i.pt | BooleanSocket |
Select the element Pt |
| i.au | BooleanSocket |
Select the element Au |
| i.hg | BooleanSocket |
Select the element Hg |
Outputs
| Name | Type | Description |
|---|---|---|
| o.selection | BooleanSocket |
The calculated selection |
| o.inverted | BooleanSocket |
The inverse of the calculated selection |
Select Nucleic Type
nodes.geometry.SelectNucleicType(and_=True, or_=False)GUI reference: Select Nucleic Type.
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| and_ | InputBoolean |
The resulting selection must overlap with this input selection | True |
| or_ | InputBoolean |
The resulting selection can be calculated from this node or be from this input selection | False |
Inputs
| Name | Type | Description |
|---|---|---|
| i.and_ | BooleanSocket |
The resulting selection must overlap with this input selection |
| i.or_ | BooleanSocket |
The resulting selection can be calculated from this node or be from this input selection |
Outputs
| Name | Type | Description |
|---|---|---|
| o.is_purine | BooleanSocket |
is_purine |
| o.is_pyrimidine | BooleanSocket |
is_pyrimidine |
Select Proximity
nodes.geometry.SelectProximity(
target_atoms=None,
subset=True,
expand=False,
distance_a=5.0,
)GUI reference: Select Proximity.
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| target_atoms | InputGeometry |
The atoms to measure the distance from. | None |
| subset | InputBoolean |
Subset of input atoms to use for proximity calculation | True |
| expand | InputBoolean |
Include an entire residue if even a single atom is within the threshold | False |
| distance_a | InputFloat |
Cutoff distance for the selection in Angstroms | 5.0 |
Inputs
| Name | Type | Description |
|---|---|---|
| i.target_atoms | GeometrySocket |
The atoms to measure the distance from. |
| i.subset | BooleanSocket |
Subset of input atoms to use for proximity calculation |
| i.expand | BooleanSocket |
Include an entire residue if even a single atom is within the threshold |
| i.distance_a | FloatSocket |
Cutoff distance for the selection in Angstroms |
Outputs
| Name | Type | Description |
|---|---|---|
| o.selection | BooleanSocket |
The calculated selection |
| o.inverted | BooleanSocket |
The inverse of the calculated selection |
Select Res ID
nodes.geometry.SelectResID(and_=True, or_=False, res_id=10)GUI reference: Select Res ID.
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| and_ | InputBoolean |
The resulting selection must overlap with this input selection | True |
| or_ | InputBoolean |
The resulting selection can be calculated from this node or be from this input selection | False |
| res_id | InputInteger |
A single res_id selection |
10 |
Inputs
| Name | Type | Description |
|---|---|---|
| i.and_ | BooleanSocket |
The resulting selection must overlap with this input selection |
| i.or_ | BooleanSocket |
The resulting selection can be calculated from this node or be from this input selection |
| i.res_id | IntegerSocket |
A single res_id selection |
Outputs
| Name | Type | Description |
|---|---|---|
| o.selection | BooleanSocket |
The calculated selection |
| o.inverted | BooleanSocket |
The inverse of the calculated selection |
Select Res ID Range
nodes.geometry.SelectResIDRange(and_=True, or_=False, min=10, max=100)GUI reference: Select Res ID Range.
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| and_ | InputBoolean |
The resulting selection must overlap with this input selection | True |
| or_ | InputBoolean |
The resulting selection can be calculated from this node or be from this input selection | False |
| min | InputInteger |
Minimum of a res_id range selection |
10 |
| max | InputInteger |
Maximum of a res_id range selection |
100 |
Inputs
| Name | Type | Description |
|---|---|---|
| i.and_ | BooleanSocket |
The resulting selection must overlap with this input selection |
| i.or_ | BooleanSocket |
The resulting selection can be calculated from this node or be from this input selection |
| i.min | IntegerSocket |
Minimum of a res_id range selection |
| i.max | IntegerSocket |
Maximum of a res_id range selection |
Outputs
| Name | Type | Description |
|---|---|---|
| o.selection | BooleanSocket |
The calculated selection |
| o.inverted | BooleanSocket |
The inverse of the calculated selection |
Select Res ID String
nodes.geometry.SelectResIDString(string='')GUI reference: Select Res ID String.
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| string | InputString |
String | '' |
Inputs
| Name | Type | Description |
|---|---|---|
| i.string | StringSocket |
String |
Outputs
| Name | Type | Description |
|---|---|---|
| o.selection | BooleanSocket |
Selection |
Select Res Name
nodes.geometry.SelectResName(
and_=True,
or_=False,
ala=False,
arg=False,
asn=False,
asp=False,
cys=False,
glu=False,
gln=False,
gly=False,
his=False,
ile=False,
leu=False,
lys=False,
met=False,
phe=False,
pro=False,
ser=False,
thr=False,
trp=False,
tyr=False,
val=False,
a=False,
c=False,
g=False,
t=False,
ra=False,
rc=False,
rg=False,
ru=False,
)GUI reference: Select Res Name.
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| and_ | InputBoolean |
The resulting selection must overlap with this input selection | True |
| or_ | InputBoolean |
The resulting selection can be calculated from this node or be from this input selection | False |
| ala | InputBoolean |
Select the residue ALA | False |
| arg | InputBoolean |
Select the residue ARG | False |
| asn | InputBoolean |
Select the residue ASN | False |
| asp | InputBoolean |
Select the residue ASP | False |
| cys | InputBoolean |
Select the residue CYS | False |
| glu | InputBoolean |
Select the residue GLU | False |
| gln | InputBoolean |
Select the residue GLN | False |
| gly | InputBoolean |
Select the residue GLY | False |
| his | InputBoolean |
Select the residue HIS | False |
| ile | InputBoolean |
Select the residue ILE | False |
| leu | InputBoolean |
Select the residue LEU | False |
| lys | InputBoolean |
Select the residue LYS | False |
| met | InputBoolean |
Select the residue MET | False |
| phe | InputBoolean |
Select the residue PHE | False |
| pro | InputBoolean |
Select the residue PRO | False |
| ser | InputBoolean |
Select the residue SER | False |
| thr | InputBoolean |
Select the residue THR | False |
| trp | InputBoolean |
Select the residue TRP | False |
| tyr | InputBoolean |
Select the residue TYR | False |
| val | InputBoolean |
Select the residue VAL | False |
| a | InputBoolean |
Select the residue A | False |
| c | InputBoolean |
Select the residue C | False |
| g | InputBoolean |
Select the residue G | False |
| t | InputBoolean |
Select the residue T | False |
| ra | InputBoolean |
Select the residue rA | False |
| rc | InputBoolean |
Select the residue rC | False |
| rg | InputBoolean |
Select the residue rG | False |
| ru | InputBoolean |
Select the residue rU | False |
Inputs
| Name | Type | Description |
|---|---|---|
| i.and_ | BooleanSocket |
The resulting selection must overlap with this input selection |
| i.or_ | BooleanSocket |
The resulting selection can be calculated from this node or be from this input selection |
| i.ala | BooleanSocket |
Select the residue ALA |
| i.arg | BooleanSocket |
Select the residue ARG |
| i.asn | BooleanSocket |
Select the residue ASN |
| i.asp | BooleanSocket |
Select the residue ASP |
| i.cys | BooleanSocket |
Select the residue CYS |
| i.glu | BooleanSocket |
Select the residue GLU |
| i.gln | BooleanSocket |
Select the residue GLN |
| i.gly | BooleanSocket |
Select the residue GLY |
| i.his | BooleanSocket |
Select the residue HIS |
| i.ile | BooleanSocket |
Select the residue ILE |
| i.leu | BooleanSocket |
Select the residue LEU |
| i.lys | BooleanSocket |
Select the residue LYS |
| i.met | BooleanSocket |
Select the residue MET |
| i.phe | BooleanSocket |
Select the residue PHE |
| i.pro | BooleanSocket |
Select the residue PRO |
| i.ser | BooleanSocket |
Select the residue SER |
| i.thr | BooleanSocket |
Select the residue THR |
| i.trp | BooleanSocket |
Select the residue TRP |
| i.tyr | BooleanSocket |
Select the residue TYR |
| i.val | BooleanSocket |
Select the residue VAL |
| i.a | BooleanSocket |
Select the residue A |
| i.c | BooleanSocket |
Select the residue C |
| i.g | BooleanSocket |
Select the residue G |
| i.t | BooleanSocket |
Select the residue T |
| i.ra | BooleanSocket |
Select the residue rA |
| i.rc | BooleanSocket |
Select the residue rC |
| i.rg | BooleanSocket |
Select the residue rG |
| i.ru | BooleanSocket |
Select the residue rU |
Outputs
| Name | Type | Description |
|---|---|---|
| o.selection | BooleanSocket |
The calculated selection |
| o.inverted | BooleanSocket |
The inverse of the calculated selection |
Select Res Whole
nodes.geometry.SelectResWhole(selection=False, expand=True)GUI reference: Select Res Whole.
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| selection | InputBoolean |
Selection of atoms to apply this node to | False |
| expand | InputBoolean |
Whether to expand the selection to the whole residue if at least one atom is selected | True |
Inputs
| Name | Type | Description |
|---|---|---|
| i.selection | BooleanSocket |
Selection of atoms to apply this node to |
| i.expand | BooleanSocket |
Whether to expand the selection to the whole residue if at least one atom is selected |
Outputs
| Name | Type | Description |
|---|---|---|
| o.selection | BooleanSocket |
The calculated selection |
Select Sphere
nodes.geometry.SelectSphere(and_=True, or_=False, object=None)GUI reference: Select Sphere.
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| and_ | InputBoolean |
The resulting selection must overlap with this input selection | True |
| or_ | InputBoolean |
The resulting selection can be calculated from this node or be from this input selection | False |
| object | InputObject |
The position from this Object will be used for the distance calculation for the selection. By default an Empty object is used, but any object can be used in principle | None |
Inputs
| Name | Type | Description |
|---|---|---|
| i.and_ | BooleanSocket |
The resulting selection must overlap with this input selection |
| i.or_ | BooleanSocket |
The resulting selection can be calculated from this node or be from this input selection |
| i.object | ObjectSocket |
The position from this Object will be used for the distance calculation for the selection. By default an Empty object is used, but any object can be used in principle |
Outputs
| Name | Type | Description |
|---|---|---|
| o.selection | BooleanSocket |
The calculated selection |
| o.inverted | BooleanSocket |
The inverse of the calculated selection |
Selected Instances
nodes.geometry.SelectedInstances(instances=None, selection=False)GUI reference: Selected Instances.
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| instances | InputGeometry |
Geometry containing instances to check if they are selected or not | None |
| selection | InputBoolean |
The selection to apply to the bounding boxes of the Instances | False |
Inputs
| Name | Type | Description |
|---|---|---|
| i.instances | GeometrySocket |
Geometry containing instances to check if they are selected or not |
| i.selection | BooleanSocket |
The selection to apply to the bounding boxes of the Instances |
Outputs
| Name | Type | Description |
|---|---|---|
| o.entirely_selected | BooleanSocket |
All points of the instances bounding box are selected |
| o.partially_selected | BooleanSocket |
Some points of the Instance’s bounding box are selected |
| o.not_selected | BooleanSocket |
No points of the Instance’s bounding box are selected |
Separate Atoms
nodes.geometry.SeparateAtoms(atoms=None, selection=True)GUI reference: Separate Atoms.
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| atoms | InputGeometry |
Atomic geometry that contains vertices and edges | None |
| selection | InputBoolean |
Selection field for which atoms to separate | True |
Inputs
| Name | Type | Description |
|---|---|---|
| i.atoms | GeometrySocket |
Atomic geometry that contains vertices and edges |
| i.selection | BooleanSocket |
Selection field for which atoms to separate |
Outputs
| Name | Type | Description |
|---|---|---|
| o.atoms | GeometrySocket |
The selected atoms |
| o.inverted | GeometrySocket |
The parts of the geometry not in the selection |
| o.index | IntegerSocket |
Index of the point before being separated. |
Separate Polymers
nodes.geometry.SeparatePolymers(atoms=None)GUI reference: Separate Polymers.
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| atoms | InputGeometry |
Atomic geometry that contains vertices and edges | None |
Inputs
| Name | Type | Description |
|---|---|---|
| i.atoms | GeometrySocket |
Atomic geometry that contains vertices and edges |
Outputs
| Name | Type | Description |
|---|---|---|
| o.peptide | GeometrySocket |
Peptide |
| o.nucleic | GeometrySocket |
Nucleic |
| o.other | GeometrySocket |
Other |