Show spheres as a Point Cloud, Instances of a mesh Icosphere, or realised Mesh instances of an Icosphere. Point cloud is best for performance and should definitely be used if rendering in Cycles.
'Instance'
scale
InputFloat
Scale the vdw_radii attribute before setting the radius for the spheres
Set the radius for the generated bonds in Angstroms
0.3
bond_find
InputBoolean
Find possible bonds for the selected atoms based on a distance search. Unselected atoms maintain any bonds they already have. Bonds that are found are all treated as single bonds
False
bond_find_scale
InputFloat
Scale the VDW radii of the atoms when searching for bonds
1.0
shade_smooth
InputBoolean
Apply smooth shading to the created geometry
True
material
InputMaterial
Material to apply to the resulting geometry
None
Inputs
Name
Type
Description
i.atoms
GeometrySocket
Atomic geometry that contains vertices and edges
i.selection
BooleanSocket
Selection of atoms to apply this style to, discarding unselected points
i.quality
IntegerSocket
A lower value results in less geometry, with a higher value meaning better looking but more dense geometry
i.sphere
MenuSocket
Show spheres as a Point Cloud, Instances of a mesh Icosphere, or realised Mesh instances of an Icosphere. Point cloud is best for performance and should definitely be used if rendering in Cycles.
i.scale
FloatSocket
Scale the vdw_radii attribute before setting the radius for the spheres
i.bond_split
MenuSocket
Bond Split
i.bond_scale
FloatSocket
Set the radius for the generated bonds in Angstroms
i.bond_find
BooleanSocket
Find possible bonds for the selected atoms based on a distance search. Unselected atoms maintain any bonds they already have. Bonds that are found are all treated as single bonds
i.bond_find_scale
FloatSocket
Scale the VDW radii of the atoms when searching for bonds
Show spheres as a Point Cloud, Instances of a mesh Icosphere, or realised Mesh instances of an Icosphere. Point cloud is best for performance and should definitely be used if rendering in Cycles.
'Point'
quality
InputInteger
Number of subdicisions when using Instances or Mesh to represent atoms
2
scale
InputFloat
Scale the vdw_radii of the atom when setting the radius of the spheres
0.8
shade_smooth
InputBoolean
Apply smooth shading when using Instances or Mesh
True
material
InputMaterial
Material to apply to the resulting geometry
None
Inputs
Name
Type
Description
i.atoms
GeometrySocket
Atomic geometry that contains vertices and edges
i.selection
BooleanSocket
Selection of atoms to apply this style to, discarding unselected points
i.sphere
MenuSocket
Show spheres as a Point Cloud, Instances of a mesh Icosphere, or realised Mesh instances of an Icosphere. Point cloud is best for performance and should definitely be used if rendering in Cycles.
i.quality
IntegerSocket
Number of subdicisions when using Instances or Mesh to represent atoms
i.scale
FloatSocket
Scale the vdw_radii of the atom when setting the radius of the spheres
Show spheres as a Point Cloud, Instances of a mesh Icosphere, or realised Mesh instances of an Icosphere. Point cloud is best for performance and should definitely be used if rendering in Cycles.
'Instance'
quality
InputInteger
A lower value results in less geometry, with a higher value meaning better looking but more dense geometry
3
scale
InputFloat
Radius of the sticks in Angstroms
0.2
shade_smooth
InputBoolean
Apply smooth shading to the created geometry
True
material
InputMaterial
Material to apply to the resulting geometry
None
Inputs
Name
Type
Description
i.atoms
GeometrySocket
Atomic geometry that contains vertices and edges
i.selection
BooleanSocket
Selection of atoms to apply this style to, discarding unselected points
i.sphere
MenuSocket
Show spheres as a Point Cloud, Instances of a mesh Icosphere, or realised Mesh instances of an Icosphere. Point cloud is best for performance and should definitely be used if rendering in Cycles.
i.quality
IntegerSocket
A lower value results in less geometry, with a higher value meaning better looking but more dense geometry