omicverse.datasets.dentate_gyrus_scvelo¶
- omicverse.datasets.dentate_gyrus_scvelo(filename='dentategyrus_scv.h5ad')[source]¶
The Dentate Gyrus dataset used in https://github.com/theislab/scvelo_notebooks/tree/master/data/DentateGyrus.
This data consists of 13,913 genes across 2,930 cells. Note this dataset is the same processed dataset from the excellent scVelo package, which is a subset of the DentateGyrus dataset.
- Return type: