omicverse.pp.identify_robust_genes¶
- omicverse.pp.identify_robust_genes(data, percent_cells=0.05)[source]¶
Identify robust genes for downstream HVG selection.
- Parameters:
data (anndata.AnnData) – AnnData object containing a gene expression matrix in
.X. Genes with zero counts across all cells are removed.percent_cells (float, default=0.05) – Minimum percentage of cells in which a gene must be detected to be marked as
robust.
- Returns:
Updates
data.varwithn_cells,percent_cells,robust, and initializeshighly_variable_featuresfromrobust.- Return type:
None