|
GMP 0.3.0
Generative Metaprogramming library for C++
|
Customize the reflection range or explicit values for an enumeration. More...
#include <meta.hpp>
Static Public Attributes | |
| static constexpr int | min |
| static constexpr int | max |
enum_traits<E> provides customization points used by the compile-time enum reflection utilities. By default, enumerator scanning uses the range [-128, 127]. Users can specialize this trait directly or use GMP_ENUM_RANGE / GMP_ENUM_VALUES to define a narrower scan range or an explicit enumerator list.
| E | The enumeration type being customized. |